#
# spec file for package libvirt
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# The configuration of libvirt is modified slightly for SLE
%define with_sle_build     %{?is_opensuse:0}%{!?is_opensuse:1}

# openSUSE13.1 and 13.2 do not understand %is_opensuse. Check for those
# explicitly and disable SLE build
%if 0%{?suse_version} == 1310 || 0%{?suse_version} == 1320
    %define with_sle_build 0
%endif

# The hypervisor drivers that run in libvirtd
%define with_xen           0%{!?_without_xen:1}
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_uml           0%{!?_without_uml:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_phyp          0%{!?_without_phyp:0}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:0}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd   0%{!?_without_storage_rbd:0}
%define with_storage_sheepdog 0
%define with_storage_gluster  0
%define with_apparmor      0%{!?_without_apparmor:1}

# Optional bits on by default
%define with_sanlock       0%{!?_without_sanlock:1}
%define with_polkit_rules  1

# A few optional bits off by default, we enable later
%define with_cgconfig      0%{!?_without_cgconfig:0}
%define with_systemd       0%{!?_without_systemd:0}
%define with_numactl       0%{!?_without_numactl:0}
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld     0%{!?_without_firewalld:0}
%define with_wireshark     0%{!?_without_wireshark:0}

# Xen no longer contains xm/xend so disable building the legacy Xen driver
%define with_xen           0

# Set the OS / architecture specific special cases

# Xen is available only on x86_64 and arm
%ifnarch x86_64 %arm aarch64
    %define with_xen       0
    %define with_libxl     0
%endif

# For SLE, further restrice Xen support to x86_64 only
%if %{with_sle_build}
    %ifarch %arm aarch64
        %define with_xen   0
        %define with_libxl 0
    %endif
%endif

# Enable numactl for most architectures. Handle aarch64 separately
%ifnarch s390 s390x %arm %ix86 aarch64
    %define with_numactl   0%{!?_without_numactl:1}
%endif

# For aarch64, numactl is only available on newer than 1320, or SLE12
# family newer than 120100
%ifarch aarch64
    %if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && ( 0%{?sle_version} > 120100 ) )
        %define with_numactl 0%{!?_without_numactl:1}
    %endif
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox      0
%endif

# Disable hypervisor drivers not supported in SLE
%if %{with_sle_build}
    %define with_openvz    0
    %define with_vbox      0
    %define with_uml       0
    %define with_vmware    0
    %define with_hyperv    0
%endif

# Enable phyp driver for IBM Power systems
%ifarch ppc64
    %define with_phyp      1
%endif

# rbd enablement is a bit tricky. For x86_64
%ifarch x86_64
# enable on anything newer than 1320, or SLE12 family newer than 120100
# use librbd-devel as build dependency
    %if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && ( 0%{?sle_version} > 120100 ) )
        %define with_storage_rbd 0%{!?_without_storage_rbd:1}
        %define with_rbd_lib     librbd-devel
    %endif
# enable for SLE12 family <= 120100 (SLE12GA/SP1, Leap 42.1)
# use ceph-devel as build dependency
    %if 0%{?suse_version} == 1315 && 0%{?sle_version} <= 120100
        %define with_storage_rbd 0%{!?_without_storage_rbd:1}
        %define with_rbd_lib     ceph-devel
    %endif
%endif

# For arm
%ifarch aarch64
# enable on anything newer than 1320, or SLE12 family newer than 120100
# use librbd-devel as build dependency
    %if 0%{?suse_version} > 1320 || ( 0%{?is_opensuse} == 0 && 0%{?sle_version} > 120100 )
        %define with_storage_rbd 0%{!?_without_storage_rbd:1}
        %define with_rbd_lib     librbd-devel
    %endif
%endif

# Support systemd on 12.1 and later
%if 0%{?suse_version} >= 1210
    %define with_systemd        0%{!?_without_systemd:1}
%endif

# libvirt commit 37397320 changed the configure check for wireshark to
# use pkgconfig, but our wireshark packages do not provide wireshark.pc.
# Disable the dissector for now
%define with_wireshark     0

# numad is used to manage the CPU and memory placement dynamically for
# qemu, lxc, and uml drivers
%if %{with_qemu} || %{with_lxc} || %{with_uml}
# Enable numad for most architectures. Handle aarch64 separately
    %ifnarch s390 s390x %arm %ix86 aarch64
        %define with_numad 0%{!?_without_numad:1}
    %endif
# For aarch64, enable on anything newer than 1320, or SLE12 family newer
# than 120100
    %ifarch aarch64
        %if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
            %define with_numad 0%{!?_without_numad:1}
        %endif
    %endif
%endif

# Force QEMU to run as qemu:qemu
%define qemu_user          qemu
%define qemu_group         qemu

# Pull in cgroups config system
%if %{with_qemu} || %{with_lxc}
    %define with_cgconfig  0%{!?_without_cgconfig:1}
%endif

%define _fwdefdir /etc/sysconfig/SuSEfirewall2.d/services

Name:           libvirt
Url:            http://libvirt.org/
Version:        2.0.0
Release:        10.22
Summary:        Library providing a simple virtualization API
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-config-network = %{version}-%{release}
Requires:       libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires:       libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_lxc}
Requires:       libvirt-daemon-driver-lxc = %{version}-%{release}
%endif
%if %{with_qemu}
Requires:       libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
%if %{with_uml}
Requires:       libvirt-daemon-driver-uml = %{version}-%{release}
%endif
%if %{with_xen}
Requires:       libvirt-daemon-driver-xen = %{version}-%{release}
%endif
%if %{with_vbox}
Requires:       libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires:       libvirt-client = %{version}-%{release}
Requires:       libvirt-daemon-driver-interface = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires:       libvirt-daemon-driver-secret = %{version}-%{release}
Requires:       libvirt-daemon-driver-storage = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-tools
BuildRequires:  libtool
# Needed for virkmodtest in 'make check'
BuildRequires:  modutils
%if %{with_systemd}
BuildRequires:  systemd
BuildRequires:  pkgconfig(systemd)
%endif
%if %{with_xen} || %{with_libxl}
BuildRequires:  xen-devel
%endif
BuildRequires:  fdupes
BuildRequires:  libattr-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libtasn1-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  python
BuildRequires:  python-xml
BuildRequires:  readline-devel
BuildRequires:  xhtml-dtd
# perl XPath is needed since we have a patch touching files that cause
# hvsupport.html to be regenerated
BuildRequires:  perl(XML::XPath)
# For pool-build probing for existing pools
BuildRequires:  libblkid-devel >= 2.17
BuildRequires:  libpciaccess0-devel >= 0.10.9
BuildRequires:  libudev-devel >= 145
BuildRequires:  libyajl-devel
%if %{with_sanlock}
BuildRequires:  sanlock-devel >= 2.4
%endif
BuildRequires:  libavahi-devel
BuildRequires:  libnl3-devel
BuildRequires:  libpcap-devel
BuildRequires:  libselinux-devel
%if %{with_apparmor}
BuildRequires:  libapparmor-devel
%endif
BuildRequires:  dnsmasq >= 2.41
BuildRequires:  iptables
# TODO BuildRequires:  iptables-ipv6
BuildRequires:  cyrus-sasl-devel
BuildRequires:  ebtables
BuildRequires:  polkit >= 0.93
BuildRequires:  polkit-devel >= 0.93
BuildRequires:  radvd
# For mount/umount in FS driver
BuildRequires:  util-linux
# For LVM drivers
BuildRequires:  lvm2
# For ISCSI driver
BuildRequires:  open-iscsi
# For disk driver
BuildRequires:  parted-devel
# For Multipath support
BuildRequires:  device-mapper-devel
%if %{with_storage_rbd}
BuildRequires:  %{with_rbd_lib}
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires:  libnuma-devel
%endif
BuildRequires:  fuse-devel >= 2.8.6
BuildRequires:  libcap-ng-devel >= 0.5.0
BuildRequires:  libnetcontrol-devel >= 0.2.0
BuildRequires:  libssh2-devel
%if %{with_esx}
BuildRequires:  libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires:  libwsman-devel >= 2.2.3
%endif
BuildRequires:  audit-devel
# we need /usr/sbin/dtrace
BuildRequires:  systemtap-sdt-devel
%if %{with_numad}
BuildRequires:  numad
%endif
%if %{with_wireshark}
BuildRequires:  wireshark-devel > 1.12.1
%endif
%if %{with_qemu}
# BuildRequire qemu-tools so configure can detect qemu-bridge-helper
# path.
BuildRequires:  qemu-tools
%endif

Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        libvirtd.init
Source4:        libvirtd-relocation-server.fw
Source99:       baselibs.conf
Source100:      %{name}-rpmlintrc
# Upstream patches
Patch0:         c8f08e48-systemd-notify-fix.patch
Patch1:         a7f84cb1-qemu-virtio-disk-error-cleanup.patch
Patch2:         60c40ce3-qemuDomainSecretDiskCapable.patch
Patch3:         fceeeda2-qemu-secinfo-hotplug-disk.patch
Patch4:         541e9ae6-cpu-vendor-crash-fix.patch
Patch5:         d53d4650-qemu-rbd-auth.patch
Patch6:         ea46e00f-virHostdevFindUSBDevice-privsyms.patch
Patch7:         e01d300b-libxl-usb-vendor.patch
Patch8:         f820d5bf6-USB-port-path-as-an-array-of-integers.patch
Patch9:         82c142b3-introduce-virDomainUSBAddressSet.patch
Patch10:        6b3e4e2b-functions-usb-controllers-to-addr.patch
Patch11:        be146b34-extend-usb-controller-model.patch
Patch12:        770bf992-libxl-usb-controller-creation.patch
Patch13:        44304c6e-libxl-usb-controller-hotplug.patch
Patch14:        f5359e55-libxl-autocreate-usb-controller.patch
Patch15:        9a361bbb-xenconfig-usb-controller-conversion.patch
Patch16:        c6f0e177-qusb-qemu-check.patch
Patch17:        70f83f9d-pci-driver-override.patch
Patch18:        36f57ad-advertise-migv3.patch
Patch19:        c0960aab-libxl-shadow-mem.patch
Patch20:        dbb14bb0-cmt-fix1.patch
Patch21:        1ac897a1-cmt-fix2.patch
Patch22:        58ba240d-cmt-fix3.patch
Patch23:        300f668c-cmt-fix4.patch
Patch24:        1fc90ae9-libxl-mig-persist.patch
Patch25:        839a0608-virtlogd-lifecycle1.patch
Patch26:        f496ce1d-virtlogd-lifecycle2.patch
Patch27:        4c600de7-libxl-schedinfo.patch
Patch28:        f4332dd2-virsh-pod-sched-fix.patch
# Patches pending upstream review
Patch100:       libxl-dom-reset.patch
# Need to go upstream
Patch150:       xen-pv-cdrom.patch
Patch151:       blockcopy-check-dst-identical-device.patch
Patch152:       libvirt-power8-models.patch
Patch153:       ppc64le-canonical-name.patch
Patch154:       libxl-set-migration-constraints.patch
Patch155:       libxl-set-cach-mode.patch
Patch156:       apparmor-fixes.patch
Patch157:       apparmor-qemu-bridge-helper.patch
Patch158:       xen-pvusb-hvm.patch
Patch159:       libxl-release-mig-port.patch
# Our patches
Patch200:       libvirtd-defaults.patch
Patch201:       libvirtd-init-script.patch
Patch202:       libvirt-guests-init-script.patch
Patch203:       virtlockd-init-script.patch
Patch204:       virtlogd-init-script.patch
Patch205:       suse-qemu-conf.patch
Patch206:       support-managed-pci-xen-driver.patch
Patch207:       systemd-service-xen.patch
Patch208:       xen-sxpr-disk-type.patch
Patch209:       libxl-support-block-script.patch
Patch210:       apparmor-no-mount.patch
Patch211:       qemu-apparmor-screenshot.patch
Patch212:       libvirt-suse-netcontrol.patch
Patch213:       lxc-wait-after-eth-del.patch
Patch214:       libxl-qemu-emulator-caps.patch
# SLES-Only patches
Patch300:       virt-create-rootfs.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libvirt is a C toolkit to interact with the virtualization
capabilities of Linux. Virtualization of the Linux Operating System means
the ability to run multiple instances of Operating Systems concurrently
on a single hardware system where the basic resources are driven by a
Linux instance. The library aims to provide long term stable C API
to interact with Linux virtualization technologies.



Authors:
--------
    Daniel Veillard <veillard@redhat.com>
    Karel Zak <kzak@redhat.com>


%package doc
Summary:        API reference and website documentation
Group:          Development/Libraries/C and C++

%description doc
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary:        Server side daemon and supporting files for libvirt library
Group:          Development/Libraries/C and C++

# All runtime requirements for the libvirt package (runtime requirements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs and virsh are in a subpackage
Requires:       %{name}-client = %{version}-%{release}

# for modprobe of pci devices
Requires:       modutils
# for /sbin/ip & /sbin/tc
Requires:       bridge-utils
Requires:       iproute
Requires:       logrotate
Requires:       udev >= 145
Recommends:     polkit >= 0.93
%ifarch i386 i586 i686 x86_64 ia64
# For virConnectGetSysinfo
Requires:       dmidecode
%endif
%if %{with_systemd}
# For service management
%{?systemd_requires}
%endif
%if %{with_numad}
Requires:       numad
%endif

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary:        Default configuration files for the libvirtd daemon
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary:        Network filter configuration files for the libvirtd
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for the libvirt daemon, used for
cleaning guest network traffic.

%package daemon-driver-network
Summary:        Network driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       dnsmasq >= 2.41
Requires:       iptables
# TODO Requires:       iptables-ipv6
Requires:       libvirt-daemon = %{version}-%{release}
Requires:       radvd

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.

%package daemon-driver-nwfilter
Summary:        A nwfilter driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       ebtables
Requires:       iptables
# TODO Requires:       iptables-ipv6
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities

%package daemon-driver-nodedev
Summary:        Nodedev driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.

%package daemon-driver-interface
Summary:        Interface driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcontrol library

%package daemon-driver-secret
Summary:        Secret driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.

%package daemon-driver-storage
Summary:        Storage driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}
Requires:       nfs-utils
# For mkfs
Requires:       util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires:       /usr/bin/qemu-img
%endif
# For LVM drivers
Requires:       lvm2
# For ISCSI driver
Requires:       open-iscsi
# For disk driver
Requires:       device-mapper
Requires:       parted
# For multipath support
Requires:       device-mapper

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.

%if %{with_qemu}

%package daemon-driver-qemu
Summary:        Qemu driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires:       /usr/bin/qemu-img
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-storage = %{version}-%{release}
# For image compression
Requires:       bzip2
Requires:       gzip
Requires:       lzop
Requires:       qemu
Requires:       xz

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using QEMU.
%endif

%if %{with_lxc}

%package daemon-driver-lxc
Summary:        LXC driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires:       libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif

%if %{with_uml}

%package daemon-driver-uml
Summary:        Uml driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-uml
The UML driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
User Mode Linux
%endif

%if %{with_xen}

%package daemon-driver-xen
Summary:        Xen driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-xen
The Xen driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using Xen.
%endif

%if %{with_vbox}

%package daemon-driver-vbox
Summary:        VirtualBox driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif

%if %{with_libxl}

%package daemon-driver-libxl
Summary:        Libxl driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using libxl.
%endif

%if %{with_qemu}

%package daemon-qemu
Summary:        Server side daemon & driver required to run QEMU guests
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-driver-interface = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires:       libvirt-daemon-driver-qemu = %{version}-%{release}
Requires:       libvirt-daemon-driver-secret = %{version}-%{release}

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU emulators
%endif

%if %{with_lxc}

%package daemon-lxc
Summary:        Server side daemon & driver required to run LXC guests
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-driver-interface = %{version}-%{release}
Requires:       libvirt-daemon-driver-lxc = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires:       libvirt-daemon-driver-secret = %{version}-%{release}
Requires:       libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif

%if %{with_uml}

%package daemon-uml
Summary:        Server side daemon & driver required to run UML guests
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-driver-interface = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires:       libvirt-daemon-driver-secret = %{version}-%{release}
Requires:       libvirt-daemon-driver-storage = %{version}-%{release}
Requires:       libvirt-daemon-driver-uml = %{version}-%{release}

%description daemon-uml
Server side daemon and driver required to manage the virtualization
capabilities of UML
%endif

%if %{with_xen} || %{with_libxl}

%package daemon-xen
Summary:        Server side daemon & driver required to run XEN guests
Group:          Development/Libraries/C and C++

Requires:       libvirt-daemon = %{version}-%{release}
    %if %{with_xen}
Requires:       libvirt-daemon-driver-xen = %{version}-%{release}
    %endif
    %if %{with_libxl}
Requires:       libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires:       libvirt-daemon-driver-interface = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires:       libvirt-daemon-driver-secret = %{version}-%{release}
Requires:       libvirt-daemon-driver-storage = %{version}-%{release}
Requires:       xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}

%package daemon-vbox
Summary:        Server side daemon & driver required to run VirtualBox guests
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon = %{version}-%{release}
Requires:       libvirt-daemon-driver-interface = %{version}-%{release}
Requires:       libvirt-daemon-driver-network = %{version}-%{release}
Requires:       libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires:       libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires:       libvirt-daemon-driver-secret = %{version}-%{release}
Requires:       libvirt-daemon-driver-storage = %{version}-%{release}
Requires:       libvirt-daemon-driver-vbox = %{version}-%{release}
Requires:       virtualbox

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%package client
Summary:        Client side library and utilities of the libvirt library
Group:          Development/Libraries/C and C++
Requires:       ncurses
Requires:       readline
# So remote clients can access libvirt over SSH tunnel
# (client invokes 'nc' against the UNIX socket on the server)
Requires:       netcat-openbsd
# Needed by libvirt-guests init script.
Requires:       gettext-runtime
# Needed by virt-pki-validate script.
Requires:       cyrus-sasl
Requires:       gnutls
# Not technically required, but makes 'out-of-box' config
# work correctly & doesn't have onerous dependencies
Requires:       cyrus-sasl-digestmd5

%description client
Shared libraries and client binaries needed to access to the
virtualization capabilities of recent versions of Linux (and other OSes).

%package devel
Summary:        Libraries, includes, etc. to compile with the libvirt library
Group:          Development/Libraries/C and C++
Requires:       %{name}-client = %{version}-%{release}
Requires:       %{name}-doc = %{version}-%{release}
Requires:       pkg-config

%description devel
Include header files & development libraries for the libvirt C library.


%if %{with_sanlock}

%package lock-sanlock
Summary:        Sanlock lock manager plugin for QEMU driver
Group:          Development/Libraries/C and C++
Requires:       sanlock >= 2.4
# for virt-sanlock-cleanup require augeas
Requires:       %{name}-client = %{version}-%{release}
Requires:       %{name}-daemon = %{version}-%{release}
Requires:       augeas

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU driver
%endif

%if %{with_wireshark}

%package -n wireshark-plugin-libvirt
Summary:        Wireshark plugin for libvirt RPC protocol
Group:          Productivity/Networking/Diagnostic
Requires:       %{name}-client = %{version}-%{release}
Requires:       wireshark

%description -n wireshark-plugin-libvirt
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%package nss
Summary:        Libvirt plugin for Name Service Switch
Group:          Development/Libraries/C and C++
Requires:       libvirt-daemon-driver-network = %{version}-%{release}

%description nss
libvirt plugin for NSS for translating domain names into IP addresses.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch100 -p1
%patch150 -p1
%patch151 -p1
%patch152 -p1
%patch153 -p1
%patch154 -p1
%patch155 -p1
%patch156 -p1
%patch157 -p1
%patch158 -p1
%patch159 -p1
%patch200 -p1
%patch201 -p1
%patch202 -p1
%patch203 -p1
%patch204 -p1
%patch205 -p1
%patch206 -p1
%patch207 -p1
%patch208 -p1
%patch209 -p1
%patch210 -p1
%patch211 -p1
%patch212 -p1
%patch213 -p1
%patch214 -p1
%patch300 -p1

%build
%if %{with_xen}
    %define arg_xen --with-xen
%else
    %define arg_xen --without-xen
%endif
%if %{with_qemu}
    %define arg_qemu --with-qemu
%else
    %define arg_qemu --without-qemu
%endif
%if %{with_openvz}
    %define arg_openvz --with-openvz
%else
    %define arg_openvz --without-openvz
%endif
%if %{with_lxc}
    %define arg_lxc --with-lxc
%else
    %define arg_lxc --without-lxc
%endif
%if %{with_vbox}
    %define arg_vbox --with-vbox
%else
    %define arg_vbox --without-vbox
%endif
%if %{with_uml}
    %define arg_uml --with-uml
%else
    %define arg_uml --without-uml
%endif
%if %{with_phyp}
    %define arg_phyp --with-phyp
%else
    %define arg_phyp --without-phyp
%endif
%if %{with_esx}
    %define arg_esx --with-esx
%else
    %define arg_esx --without-esx
%endif
%if %{with_vmware}
    %define arg_vmware --with-vmware
%else
    %define arg_vmware --without-vmware
%endif
%if %{with_hyperv}
    %define arg_hyperv --with-hyperv
%else
    %define arg_hyperv --without-hyperv
%endif
%if %{with_libxl}
    %define arg_libxl --with-libxl
%else
    %define arg_libxl --without-libxl
%endif
%if %{with_storage_rbd}
    %define arg_storage_rbd --with-storage-rbd
%else
    %define arg_storage_rbd --without-storage-rbd
%endif
%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog --with-storage-sheepdog
%else
    %define arg_storage_sheepdog --without-storage-sheepdog
%endif
%if %{with_storage_gluster}
    %define arg_storage_gluster --with-storage-gluster
%else
    %define arg_storage_gluster --without-storage-gluster
%endif
%if %{with_numactl}
    %define arg_numactl --with-numactl
%else
    %define arg_numactl --without-numactl
%endif
%if %{with_numad}
    %define arg_numad --with-numad
%else
    %define arg_numad --without-numad
%endif
%if %{with_apparmor}
    %define arg_apparmor --with-apparmor
    %define arg_apparmor_profiles --with-apparmor-profiles
%else
    %define arg_apparmor --without-apparmor
%endif
%if %{with_sanlock}
    %define arg_sanlock --with-sanlock
%else
    %define arg_sanlock --without-sanlock
%endif
%if %{with_systemd}
    %define arg_init_script --with-init-script=systemd
%else
    %define arg_init_script --with-init-script=redhat
%endif
%if %{with_firewalld}
    %define arg_firewalld --with-firewalld
%else
    %define arg_firewalld --without-firewalld
%endif
%if %{with_wireshark}
    %define arg_wireshark --with-wireshark-dissector
%else
    %define arg_wireshark --without-wireshark-dissector
%endif

%define arg_selinux_mount --with-selinux-mount="/selinux"

# x86_64 UEFI firmwares
# To more closely resemble actual hardware, we use the firmwares with
# embedded Microsoft keys
LOADERS="/usr/share/qemu/ovmf-x86_64-ms-code.bin:/usr/share/qemu/ovmf-x86_64-ms-vars.bin"
# aarch64 UEFI firmwares
LOADERS="$LOADERS:/usr/share/qemu/aavmf-aarch64-code.bin:/usr/share/qemu/aavmf-aarch64-vars.bin"
%define arg_loader_nvram --with-loader-nvram="$LOADERS"

autoreconf -f -i
export CFLAGS="$RPM_OPT_FLAGS"
%configure --disable-static --with-pic \
           %{?arg_xen} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           --with-sasl \
           --with-avahi \
           --with-polkit \
           --with-libvirtd \
           %{?arg_uml} \
           %{?arg_phyp} \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           --without-xenapi \
           --without-vz \
           --without-bhyve \
           --with-interface \
           --with-network \
           --with-storage-fs \
           --with-storage-lvm \
           --with-storage-iscsi \
           --with-storage-disk \
           --with-storage-mpath \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_numactl} \
           %{?arg_numad} \
           --with-capng \
           --with-fuse \
           --without-netcf \
           --with-netcontrol \
           --with-selinux \
           %{?arg_selinux_mount} \
           %{?arg_apparmor} \
           %{?arg_apparmor_profiles} \
           --with-udev \
           --with-yajl \
           %{?arg_sanlock} \
           --with-libpcap \
           --with-macvtap \
           --with-audit \
           --with-dtrace \
           --with-driver-modules \
           %{?arg_firewalld} \
           %{?arg_wireshark} \
           --with-nss-plugin \
           --libexecdir=%{_libdir}/%{name} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           %{?arg_loader_nvram} \
           --without-login-shell \
           %{arg_init_script} \
           ac_cv_path_MODPROBE=/sbin/modprobe \
           ac_cv_path_UDEVADM=/sbin/udevadm \
           ac_cv_path_SHOWMOUNT=/usr/sbin/showmount
make V=1 %{?jobs:-j%jobs} DOCS_DIR=%{_docdir}/%{name}-python EXAMPLE_DIR=%{_docdir}/%{name}-python/examples HTML_DIR=%{_docdir}/%{name}
gzip -9 ChangeLog

%install
%makeinstall SYSTEMD_UNIT_DIR=%{_unitdir} DOCS_DIR=%{_docdir}/%{name}-python EXAMPLE_DIR=%{_docdir}/%{name}-python/examples HTML_DIR=%{_docdir}/%{name}
make -C examples distclean
cp examples/lxcconvert/virt-lxc-convert $RPM_BUILD_ROOT%{_bindir}
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{_libdir}/wireshark/plugins/*/libvirt.la
mv $RPM_BUILD_ROOT%{_libdir}/wireshark/plugins/*/libvirt.so \
   $RPM_BUILD_ROOT%{_libdir}/wireshark/plugins/libvirt.so
%endif
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/connection-driver/*.a
# remove currently unsupported locale(s)
for dir in $RPM_BUILD_ROOT/usr/share/locale/*
do
  sdir=`echo $dir | sed "s|$RPM_BUILD_ROOT||"`
  if test -d $sdir ; then continue ; fi
  rm -rfv "$dir"
done
# temporarily remove polkit ACL policiy configuration - bnc#827644
rm -f $RPM_BUILD_ROOT/%{_datadir}/polkit-1/actions/org.libvirt.api.policy

mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/libvirt
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/libvirt/hooks
%find_lang %{name}
# Add a README to the libvirt package with a note about the empty
# file list
cat > $RPM_BUILD_ROOT%{_docdir}/libvirt/libvirt.README << 'EOF'
The libvirt package no longer contains any files.  It exists now
only to fulfill its 'Provides' contract.
EOF
install -d -m 0755 $RPM_BUILD_ROOT%{_localstatedir}/lib/libvirt/dnsmasq/
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%if %{with_lxc}
cat > $RPM_BUILD_ROOT%{_docdir}/libvirt/libvirt-daemon-lxc.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing LXC.
EOF
%else
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if %{with_qemu}
cat > $RPM_BUILD_ROOT%{_docdir}/libvirt/libvirt-daemon-qemu.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing QEMU/KVM.
EOF
%else
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if %{with_uml}
cat > $RPM_BUILD_ROOT%{_docdir}/libvirt/libvirt-daemon-uml.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing UML.
EOF
%else
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.uml
%endif
%if %{with_vbox}
cat > $RPM_BUILD_ROOT%{_docdir}/libvirt/libvirt-daemon-vbox.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing VirtualBox.
EOF
%endif
%if %{with_xen} || %{with_libxl}
cat > $RPM_BUILD_ROOT%{_docdir}/libvirt/libvirt-daemon-xen.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing Xen.
EOF
%endif
%if ! %{with_libxl}
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif
%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

# init scripts
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/init.d
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates
# Currently using our own libvirtd init script
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/libvirtd
%if %{with_systemd}
ln -s %{_sbindir}/service $RPM_BUILD_ROOT%{_sbindir}/rclibvirtd
%else
install %SOURCE3 $RPM_BUILD_ROOT%{_sysconfdir}/init.d/libvirtd
ln -s /etc/init.d/libvirtd $RPM_BUILD_ROOT%{_sbindir}/rclibvirtd
%endif
mv $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/libvirtd $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates/sysconfig.libvirtd
rm -f $RPM_BUILD_ROOT/usr/lib/sysctl.d/60-libvirtd.conf
# For other services, use the in-tree scripts
%if %{with_systemd}
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/virtlogd
ln -s %{_sbindir}/service $RPM_BUILD_ROOT%{_sbindir}/rcvirtlogd
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/virtlockd
ln -s %{_sbindir}/service $RPM_BUILD_ROOT%{_sbindir}/rcvirtlockd
%else
mv $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/virtlogd $RPM_BUILD_ROOT%{_sysconfdir}/init.d/virtlogd
ln -s /etc/init.d/virtlogd $RPM_BUILD_ROOT%{_sbindir}/rcvirtlogd
mv $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/virtlockd $RPM_BUILD_ROOT%{_sysconfdir}/init.d/virtlockd
ln -s /etc/init.d/virtlockd $RPM_BUILD_ROOT%{_sbindir}/rcvirtlockd
%endif
mv $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/virtlogd $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates/sysconfig.virtlogd
mv $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/virtlockd $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates/sysconfig.virtlockd
#install firewall definitions format is described here:
#/usr/share/SuSEfirewall2/services/TEMPLATE
mkdir -p $RPM_BUILD_ROOT/%{_fwdefdir}
install -m 644 %{S:4} $RPM_BUILD_ROOT/%{_fwdefdir}/libvirtd-relocation-server
%if %{with_systemd}
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/libvirt-guests
ln -s %{_sbindir}/service $RPM_BUILD_ROOT%{_sbindir}/rclibvirt-guests
%else
mv $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/libvirt-guests $RPM_BUILD_ROOT%{_sysconfdir}/init.d/libvirt-guests
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
ln -s %{_sysconfdir}/init.d/libvirt-guests $RPM_BUILD_ROOT%{_sbindir}/rclibvirt-guests
%endif
mv $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/libvirt-guests $RPM_BUILD_ROOT%{_localstatedir}/adm/fillup-templates/sysconfig.libvirt-guests
%ifarch %{power64} s390x x86_64
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
%endif
%fdupes -s $RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%check
cd tests
SKIP_TESTS=""
# These tests don't current work in a mock build root
# virnetsockettest: needs unsupported linux-user syscalls
SKIP_TESTS="$SKIP_TESTS virnetsockettest"
# virportallocatortest fails on aarch64 due to unsupported IPV6_V6ONLY flag
%ifarch aarch64
SKIP_TESTS="$SKIP_TESTS virportallocatortest"
%endif
for i in $SKIP_TESTS
do
  rm -f $i
  printf 'int main(void) { return 0; }' > $i.c
done
make

if ! make check VIR_TEST_DEBUG=1
then
  cat test-suite.log || true
  exit 1
fi

%pre daemon
%if %{with_systemd}
%service_add_pre libvirtd.service
%service_add_pre virtlockd.service virtlockd.socket
%service_add_pre virtlogd.service virtlogd.socket
%endif
%{_bindir}/getent group libvirt >/dev/null || \
  %{_sbindir}/groupadd -r libvirt || :

%post daemon
/sbin/ldconfig
%if %{with_systemd}
%service_add_post libvirtd.service
%service_add_post virtlockd.service virtlockd.socket
%service_add_post virtlogd.service virtlogd.socket
%endif
%{fillup_only -n libvirtd}
%{fillup_only -n virtlockd}
%{fillup_only -n virtlogd}

%preun daemon
%if %{with_systemd}
%service_del_preun libvirtd.service
%service_del_preun virtlockd.service virtlockd.socket
%service_del_preun virtlogd.service virtlogd.socket
%else
%stop_on_removal libvirtd
%stop_on_removal virtlockd
%stop_on_removal virtlogd
%endif

%postun daemon
/sbin/ldconfig
%if %{with_systemd}
# On upgrade, defer restarting daemons until %posttrans
if test $1 -eq 0 ; then
    for service in libvirtd virtlockd virtlogd ; do
        rm -f "/var/lib/systemd/migrated/$service" 2> /dev/null || :
    done
    /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi
%else
%restart_on_update libvirtd
%restart_on_update virtlockd
%restart_on_update virtlogd
%endif
%insserv_cleanup

%posttrans daemon
# All connection drivers should be installed post transaction.
# Time to restart daemons.
%if %{with_systemd}
if test "$YAST_IS_RUNNING" != "instsys" -a "$DISABLE_RESTART_ON_UPDATE" != yes ; then
    for service in libvirtd virtlockd virtlogd ; do
        /usr/bin/systemctl try-restart ${service}.service >/dev/null 2>&1 || :
    done
fi
%endif

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
%if %{with_systemd}
        /usr/bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
            /usr/bin/systemctl enable virtlogd.socket || :
        /usr/bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
            /usr/bin/systemctl start virtlogd.socket || :
%else
        /sbin/chkconfig libvirtd 1>/dev/null 2>&1 &&
            /sbin/chkconfig virtlogd on || :
        /sbin/service libvirtd status 1>/dev/null 2>&1 &&
            /sbin/service virtlogd start || :
%endif
fi

%post daemon-config-network
# Install the default network if one doesn't exist
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    UUID=`/usr/bin/uuidgen`
    sed -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
fi

%pre client
%if %{with_systemd}
%service_add_pre libvirt-guests.service
%endif

%post client
/sbin/ldconfig
%if %{with_systemd}
%service_add_post libvirt-guests.service
%endif
%{fillup_only -n libvirt-guests}

%preun client
%if %{with_systemd}
%service_del_preun libvirt-guests.service
%else
%stop_on_removal libvirt-guests
%endif
if [ $1 = 0 ]; then
    rm -f /var/lib/libvirt/libvirt-guests
fi

%postun client
/sbin/ldconfig
%if %{with_systemd}
%service_del_postun libvirt-guests.service
%endif
%insserv_cleanup

%post nss
/sbin/ldconfig

%postun nss
/sbin/ldconfig

%files
%doc %{_docdir}/%{name}/libvirt.README

%files daemon
%{_sbindir}/libvirtd
%{_sbindir}/virtlogd
%{_sbindir}/virtlockd
%dir %{_libdir}/%{name}
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/hooks
%{_localstatedir}/adm/fillup-templates/sysconfig.libvirtd
%{_localstatedir}/adm/fillup-templates/sysconfig.virtlogd
%{_localstatedir}/adm/fillup-templates/sysconfig.virtlockd
%if %{with_systemd}
%{_unitdir}/libvirtd.service
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%else
%config /etc/init.d/libvirtd
%config /etc/init.d/virtlogd
%config /etc/init.d/virtlockd
%endif
%{_sbindir}/rclibvirtd
%{_sbindir}/rcvirtlogd
%{_sbindir}/rcvirtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%dir %{_datadir}/augeas/
%dir %{_datadir}/augeas/lenses
%dir %{_datadir}/augeas/lenses/tests
%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%dir %{_localstatedir}/lib/libvirt/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/
%dir %attr(0755, root, root) %{_libdir}/%{name}/lock-driver
%attr(0755, root, root) %{_libdir}/%{name}/lock-driver/lockd.so
%if %{with_polkit_rules}
%{_datadir}/polkit-1/rules.d/50-libvirt.rules
%endif
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_iohelper
%doc %{_mandir}/man8/libvirtd.8*
%doc %{_mandir}/man8/virtlogd.8*
%doc %{_mandir}/man8/virtlockd.8*
%if %{with_apparmor}
%dir %{_sysconfdir}/apparmor.d
%dir %{_sysconfdir}/apparmor.d/abstractions
%dir %{_sysconfdir}/apparmor.d/libvirt
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.sbin.libvirtd
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.lib.libvirt.virt-aa-helper
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/libvirt-qemu
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/libvirt-lxc
%config(noreplace) %{_sysconfdir}/apparmor.d/libvirt/TEMPLATE.lxc
%config(noreplace) %{_sysconfdir}/apparmor.d/libvirt/TEMPLATE.qemu
%{_libdir}/%{name}/virt-aa-helper
%endif
%config %{_fwdefdir}/libvirtd-relocation-server

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml

%files daemon-config-nwfilter
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_leaseshelper
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%files daemon-driver-nodedev
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%files daemon-driver-secret
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so

%files daemon-driver-storage
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_parthelper
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so

%if %{with_qemu}

%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%endif

%if %{with_lxc}

%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_lxc
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%attr(0755, root, root) %{_bindir}/virt-lxc-convert
%{_bindir}/virt-create-rootfs
%doc %{_mandir}/man1/virt-create-rootfs.1*
%endif

%if %{with_uml}

%files daemon-driver-uml
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.uml
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/uml/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_uml.so
%endif

%if %{with_xen}

%files daemon-driver-xen
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_xen.so
%endif

%if %{with_libxl}

%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}

%files daemon-driver-vbox
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_qemu}

%files daemon-qemu
%doc %{_docdir}/%{name}/libvirt-daemon-qemu.README
%endif

%if %{with_lxc}

%files daemon-lxc
%doc %{_docdir}/%{name}/libvirt-daemon-lxc.README
%endif

%if %{with_uml}

%files daemon-uml
%doc %{_docdir}/%{name}/libvirt-daemon-uml.README
%endif

%if %{with_xen} || %{with_libxl}

%files daemon-xen
%doc %{_docdir}/%{name}/libvirt-daemon-xen.README
%endif

%if %{with_vbox}

%files daemon-vbox
%doc %{_docdir}/%{name}/libvirt-daemon-vbox.README
%endif

%files client -f %{name}.lang
%doc AUTHORS ChangeLog.gz NEWS README COPYING COPYING.LESSER TODO
%doc %{_mandir}/man1/virsh.1*
%doc %{_mandir}/man1/virt-admin.1*
%doc %{_mandir}/man1/virt-xml-validate.1*
%doc %{_mandir}/man1/virt-pki-validate.1*
%doc %{_mandir}/man1/virt-host-validate.1*
%config(noreplace) %{_sysconfdir}/%{name}/libvirt.conf
%config(noreplace) %{_sysconfdir}/%{name}/libvirt-admin.conf
%{_bindir}/virsh
%{_bindir}/virt-admin
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate
%dir %{_libdir}/%{name}
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%attr(0755, root, root) %{_libdir}/%{name}/libvirt-guests.sh
%{_localstatedir}/adm/fillup-templates/sysconfig.libvirt-guests
%if %{with_systemd}
%{_unitdir}/libvirt-guests.service
%else
%config /etc/init.d/libvirt-guests
%endif
%{_sbindir}/rclibvirt-guests

%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/

%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domaincaps.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storagecommon.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagevol.rng
%{_datadir}/libvirt/cpu_map.xml
%{_datadir}/libvirt/libvirtLogo.png
%dir %{_sysconfdir}/sasl2/
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%{_includedir}/libvirt
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc
%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml

%files doc
# Website
%dir %{_docdir}/libvirt
%doc %{_docdir}/%{name}/*.png
%doc %{_docdir}/%{name}/*.html
%doc %{_docdir}/%{name}/*.gif
%doc %{_docdir}/%{name}/*.css
%doc %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/internals

# API docs
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*

%if %{with_sanlock}

%files lock-sanlock
%doc %{_mandir}/man8/virt-sanlock-cleanup.8*
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/%{name}/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/%{name}/libxl-sanlock.conf
    %endif
%dir %{_libdir}/%{name}/lock-driver/
%attr(0755, root, root) %{_libdir}/%{name}/lock-driver/sanlock.so
%dir %{_datadir}/augeas/
%dir %{_datadir}/augeas/lenses
%dir %{_datadir}/augeas/lenses/tests
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/sanlock
%{_sbindir}/virt-sanlock-cleanup
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_sanlock_helper
%endif

%if %{with_wireshark}

%files -n wireshark-plugin-libvirt
%{_libdir}/wireshark/plugins/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2

%changelog
* Fri Oct 14 2016 jfehlig@suse.com
- libxl: fix leaking of migration ports
  libxl-release-mig-port.patch
  bsc#1005288
* Wed Sep 28 2016 jfehlig@suse.com
- libxl: fix handling of credit scheduler weight parameter
  4c600de7-libxl-schedinfo.patch,
  f4332dd2-virsh-pod-sched-fix.patch
  bsc#1001698
- virtlogd.socket: Tie lifecycle to libvirtd.service
  839a0608-virtlogd-lifecycle1.patch,
  f496ce1d-virtlogd-lifecycle2.patch
  bsc#1001446
* Wed Sep 21 2016 jfehlig@suse.com
- libxl: support VIR_MIGRATE_PERSIST_DEST migration flag
  1fc90ae9-libxl-mig-persist.patch
  bsc#996020
* Wed Sep 21 2016 cbosdonnat@suse.com
- Don't provide empty usb device list to libxl.
  xen-pvusb-hvm.patch
  bsc#998005
* Fri Sep 16 2016 jfehlig@suse.com
- cpu_x86: Fix host-model CPUs on hosts with CMT
  dbb14bb0-cmt-fix1.patch, 1ac897a1-cmt-fix2.patch,
  58ba240d-cmt-fix3.patch, 300f668c-cmt-fix4.patch
  bsc#998389
* Tue Sep  6 2016 jfehlig@suse.com
- libxl: allow libxl to calculate shadow mem requirements
  c0960aab-libxl-shadow-mem.patch
  bsc#997278
- libxl: advertise support for migration V3
  36f57ad-advertise-migv3.patch
  bsc#996020
* Tue Sep  6 2016 jfehlig@suse.com
- Replace pci-use-driver-override-sysfs.patch with upstream variant
  70f83f9d-pci-driver-override.patch
  bsc#986718
* Mon Sep  5 2016 cbosdonnat@suse.com
- Updated patches with the version accepted upstream. bsc#989646
  * libxl-usb-vendor.patch replaced by
    e01d300b-libxl-usb-vendor.patch
  * virHostdevFindUSBDevice-privsyms.patch replaced by
    ea46e00f-virHostdevFindUSBDevice-privsyms.patch
- Add USB Controller support for libxl driver. bsc#989646
    f820d5bf6-USB-port-path-as-an-array-of-integers.patch
    82c142b3-introduce-virDomainUSBAddressSet.patch
    6b3e4e2b-functions-usb-controllers-to-addr.patch
    44304c6e-libxl-usb-controller-hotplug.patch
    770bf992-libxl-usb-controller-creation.patch
    9a361bbb-xenconfig-usb-controller-conversion.patch
    be146b34-extend-usb-controller-model.patch
    c6f0e177-qusb-qemu-check.patch
    f5359e55-libxl-autocreate-usb-controller.patch
* Mon Aug 29 2016 cbosdonnat@suse.com
- Reintroduce mistakenly removed virt-create-rootfs.
  virt-create-rootfs.patch. bsc#995981
* Wed Aug 17 2016 jfehlig@suse.com
- Replace qemu-auth-AEX-fix.patch with upstream variant
  d53d4650-qemu-rbd-auth.patch
  bsc#988998
* Wed Aug 17 2016 jfehlig@suse.com
- libxl: allow vendor/product addressing for USB hostdevs
  virHostdevFindUSBDevice-privsyms.patch, libxl-usb-vendor.patch
  bsc#989646
* Sat Aug 13 2016 jfehlig@suse.com
- Replace cpumodel-vendor-crash-fix.patch with upstream variant
  541e9ae6-cpu-vendor-crash-fix.patch
  bsc#992425
* Fri Aug 12 2016 jfehlig@suse.com
- qemu: fix auth for curl, iscsi, and rbd network disks
  a7f84cb1-qemu-virtio-disk-error-cleanup.patch,
  60c40ce3-qemuDomainSecretDiskCapable.patch,
  fceeeda2-qemu-secinfo-hotplug-disk.patch, qemu-auth-AEX-fix.patch
  bsc#988998
* Fri Aug  5 2016 jfehlig@suse.com
- cpu_x86: fix libvirtd segfault when host cpu is 'qemu64'
  cpumodel-vendor-crash-fix.patch
  bsc#992425
* Fri Aug  5 2016 cbosdonnat@suse.com
- bsc#988279. Move the qemu-bridge-helper apparmor profile from the
  qemu abstraction to the usr.sbin.libvirtd profile.
  apparmor-qemu-bridge-helper.patch
* Wed Aug  3 2016 jfehlig@suse.com
- spec: minor improvements to logic enabling numactl and numad
  support and fix nested if indentation
  FATE#319979
* Tue Aug  2 2016 jfehlig@suse.com
- Update patches providing support for driver_override sysfs
  interface with latest upstream variant. Dropped
  pci-simplify-stub.patch and updated
  pci-use-driver-override-sysfs.patch
  bsc#986718
* Sat Jul 30 2016 jfehlig@suse.com
- spec: enable numactl and numad support for aarch64
  FATE#319979, bsc#991377
* Fri Jul 15 2016 jfehlig@suse.com
- BuildRequires: use librbd-devel instead of ceph-devel
- Enable rbd support for aarch64
  bsc#979473
* Thu Jul 14 2016 jfehlig@suse.com
- Use driver_override sysfs interface for binding/unbinding
  PCI stub drivers
  pci-simplify-stub.patch, pci-use-driver-override-sysfs.patch
  bsc#986718
* Tue Jul 12 2016 jfehlig@suse.com
- systemd: fix ready notification on abstract socket
  c8f08e48-systemd-notify-fix.patch
  boo#987668
* Fri Jul  1 2016 jfehlig@suse.com
- Update to libvirt 2.0.0
  - Change version scheme to match libvirt's time-driven release
    schedule. <major> will be incremented on first release of
    new calendar year, <minor> on each monthly release, and
    <micro> on stable branch maintenance release
  - Include libvirt-admin utility and API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    apparmor-dont-scrub-environment-of-virtlogd-process.patch,
    e33cd67a-xenconfig-backendtype-fix.patch
  - FATE#316228, FATE#316628, FATE#319531, FATE#319810,
    FATE#320490
* Mon Jun 20 2016 jfehlig@suse.com
- spec: Recent simplification allows using a common spec file for
  SLE and openSUSE
* Thu Jun 16 2016 jfehlig@suse.com
- xenconfig: fix conversion of <driver> to backendtype
  e33cd67a-xenconfig-backendtype-fix.patch
  bsc#984798
* Wed Jun 15 2016 jfehlig@suse.com
- Advertise aarch64 UEFI firmware paths
  - adjust spec file to include aarch64 paths in
    '--with-loader-nvram=' configure option
  - adjust qemu.conf 'nvram' option to include the SUSE paths
  bsc#981836, bsc#983747
* Thu Jun  9 2016 jfehlig@suse.com
- apparmor: Don't scrub environment of virtlogd process
  apparmor-dont-scrub-environment-of-virtlogd-process.patch
  boo#980441
* Mon Jun  6 2016 jfehlig@suse.com
- Update to libvirt 1.3.5
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    e4d131b8-mv-virDomainDefPostParseInternal.patch,
    3e428670-post-parse-implicit-video.patch,
    538012c8-default-vram.patch, 96b21fb0-vram-tests.patch,
    400e716d-libxl-noprope-emulator.patch,
    b90c4b5f-tests-use-qemu-xen.patch,
    libxl-api-version4.4.patch,
    libxl-migv2-save-restore.patch, libxl-migv2-migration.patch,
    a1c9a81a-libxl-rbd-fix.patch,
    ba566428-libxl-dom-iface-addrs.patch
  - FATE#316228, FATE#316628, FATE#319531, FATE#319810,
    FATE#320490
  - Includes fixes for bsc#903757, bsc#936524, bsc#948686,
    bsc#952889, bsc#956298, bsc#960305, and bsc#964465
- spec: simplify and cleanup by removing many conditionals that
  are never toogled. Also drop conditionals for suse_version <
  1310
* Wed May 25 2016 jfehlig@suse.com
-  libxl: add domainInterfaceAddresses API
  ba566428-libxl-dom-iface-addrs.patch
  bsc#979425
* Wed May 25 2016 jfehlig@suse.com
- libxl: default to qemu driver for network disks
  a1c9a81a-libxl-rbd-fix.patch
  boo#981094
* Wed May 18 2016 jfehlig@suse.com
- spec: Remove %%defattr usage
  Inspired by upstream commit 90f9193c
* Fri May 13 2016 jfehlig@suse.com
- Fix default video RAM setting
  e4d131b8-mv-virDomainDefPostParseInternal.patch,
  3e428670-post-parse-implicit-video.patch,
  538012c8-default-vram.patch, 96b21fb0-vram-tests.patch,
  400e716d-libxl-noprope-emulator.patch,
  b90c4b5f-tests-use-qemu-xen.patch
  bsc#979397
* Wed May  4 2016 jfehlig@suse.com
- libxl: support Xen migration stream V2
  libxl-api-version4.4.patch, libxl-migv2-save-restore.patch,
  libxl-migv2-migration.patch
  bsc#978361
* Tue May  3 2016 jfehlig@suse.com
- Update to libvirt 1.3.4
  - Add support for migration data compression in QEMU driver
  - Drop libvirtd.socket
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches: 216650f1-libxl-build-fix.patch,
    6d8b6d28-mark-implicit-video-primary.patch,
    03e8d5fb-qemu-perf-memory-corruption.patch,
    libvirtd-systemd-socket.patch
  - FATE#316228, FATE#316628, FATE#319531, FATE#319810,
    FATE#320490
* Mon Apr 18 2016 jfehlig@suse.com
- qemu: perf: Fix crash/memory corruption on failed VM start
  03e8d5fb-qemu-perf-memory-corruption.patch
  bsc#977131
* Mon Apr 18 2016 jfehlig@suse.com
- Fix setting implicit video devices as primary
  6d8b6d28-mark-implicit-video-primary.patch
  bsc#977150
* Tue Apr 12 2016 jfehlig@suse.com
- Update to libvirt 1.3.3
  - perf events
  - post-copy migration support
  - NSS module
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Add rpmlintrc file to filter shlib-policy-name-error for
    new libnss_libvirt plugin
  - FATE#316228, FATE#316628, FATE#319531, FATE#319810,
    FATE#320490
- Fix build with Xen4.7
  216650f1-libxl-build-fix.patch
* Fri Mar 18 2016 jfehlig@suse.com
- spec: restart daemons in %%posttrans after connection drivers
  have been processed
  bsc#854343, bsc#968483
* Thu Mar  3 2016 jfehlig@suse.com
- libxl: advertise system qemu instead of qemu-xen in caps
  libxl-qemu-emulator-caps.patch
  FATE#320638
* Tue Mar  1 2016 jfehlig@suse.com
- Update to libvirt 1.3.2
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - FATE#319531, FATE#319810, FATE#320490
* Thu Feb 18 2016 jfehlig@suse.com
- libxl: Add support for block-{dmmd,drbd,npiv} scripts
  libxl-support-block-script.patch
  bsc#954872 and FATE#319810
* Thu Jan 28 2016 jfehlig@suse.com
- Update to libvirt 1.3.1
  - CVE-2015-5313
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches: ba25c214-libxl-log-level.patch,
    virt-aa-helper-rw-mounts.patch,
    disable-virCgroupGetPercpuStats-test.patch
  - FATE#319531, FATE#320490
* Tue Dec 29 2015 jfehlig@suse.com
- Update to libvirt 1.2.18.2 stable release
  - Inherit many upstream bug fixes, including CVE-2015-5313
    bsc#953110
  - Drop patches included in the stable release
    a1bdf04b-apparmor-dominfo.patch
* Tue Nov 17 2015 cbosdonnat@suse.com
- Don't add apparmor deny rw rule for 9P readonly mounts.
  bsc#952849. virt-aa-helper-rw-mounts.patch
* Fri Oct 16 2015 cbosdonnat@suse.com
- spec: remove all dependencies on apparmor to keep it optional.
  bsc#949793
* Tue Oct 13 2015 jfehlig@suse.com
- xenconfig: set disk type to BLOCK when driver is not tap or file
  xend-sxpr-disk-type.patch
  bsc#938228
* Fri Oct  9 2015 jfehlig@suse.com
- spec: the libvirt apparmor profiles #include files from the
  apparmor-profiles package, thus should have a dependency on it
  bsc#949793
* Tue Oct  6 2015 cbosdonnat@suse.com
- Fix profile_status to distringuish between errors and unconfined
  domains. a1bdf04b-apparmor-dominfo.patch. bsc#948516
* Wed Sep 23 2015 jfehlig@suse.com
- Update to libvirt 1.2.18.1 stable release
  - Inherit many upstream bug fixes
  - Drop patches included in the stable release
    15120b8c-libxl-no-resume-on-suspend-fail.patch,
    269d39af-storage-allocation-fix.patch,
    26c5fa3a-virt-aa-helper-missing-doc.patch,
    2f01cfdf-virt-aa-helper-allow-ovmf.patch,
    3468542f-virFileUnlink.patch,
    44a54eb0-libxl-fix-refcnt-MigrationDstArgs.patch,
    52970dec-virt-aa-helper-improve-valid-path.patch,
    56945e13-libxl-AttachDeviceConfig-hostdev.patch,
    60acb38-revert-curmem-inactive-dom.patch,
    8b1d84e6-refreshVol-failure.patch,
    91fdcefa-virt-aa-helper-allow-nvram.patch,
    d25a5e08-virt-aa-helper-simplify-restriction-logic.patch
    e0025d29-storage-mode-check.patch,
    e80b84a7-libxl-acquire-job-on-migrate.patch
  - Drop signature file. Stable releases are not signed
  - FATE#314466, FATE#314497, FATE#315157, FATE#318383
* Thu Sep 17 2015 cyliu@suse.com
- bsc#945962: SLES12 SP1 Beta3 - Pass-through NIC device via virsh
  not available to VM.
  56945e13-libxl-AttachDeviceConfig-hostdev.patch
* Tue Sep 15 2015 jfehlig@suse.com
- libxl: set driver log level to the log_level specified in
  libvirtd.conf
  ba25c214-libxl-log-level.patch
  bsc#945796
* Mon Sep 14 2015 cbosdonnat@suse.com
- CVE-2015-5247 - denial of service through root-squash NFS storage
  bsc#945645
  3468542f-virFileUnlink.patch
  8b1d84e6-refreshVol-failure.patch
  e0025d29-storage-mode-check.patch
* Fri Aug 28 2015 jfehlig@suse.com
- Replace local libxl patch with upstream variants
  Dropped:
  0003-libxl-fix-ref-counting-of-libxlMigrationDstArgs.patch
  0004-libxl-don-t-attempt-to-resume-domain-when-suspend-fa.patch
  0005-libxl-acquire-a-job-when-receiving-a-migrating-domai.patch
  Added:
  44a54eb0-libxl-fix-refcnt-MigrationDstArgs.patch
  15120b8c-libxl-no-resume-on-suspend-fail.patch
  e80b84a7-libxl-acquire-job-on-migrate.patch
  bsc#936185
- Added another virt-aa-helper upstream patch
  52970dec-virt-aa-helper-improve-valid-path.patch
  lp#1483071
- Added upstream patch to fix libvirt-tck memory balloon test
  failure on Xen
  60acb38-revert-curmem-inactive-dom.patch
* Wed Aug 26 2015 cbosdonnat@suse.com
- Fix generated apparmor profile to allow access to ovmf and nvram.
  26c5fa3a-virt-aa-helper-missing-doc.patch
  2f01cfdf-virt-aa-helper-allow-ovmf.patch
  91fdcefa-virt-aa-helper-allow-nvram.patch
  d25a5e08-virt-aa-helper-simplify-restriction-logic.patch
  lp#1483071
* Mon Aug 24 2015 jfehlig@suse.com
- storage: only run safezero if allocation is > 0
  269d39af-storage-allocation-fix.patch
  bsc#942085
* Wed Aug  5 2015 jfehlig@suse.com
- Update to libvirt 1.2.18
  - libxl: support dom0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches: 45697fe5-libxl-support-dom0.patch,
    e9c27344-libxl-fix-virDomainObj-state.patch,
    4ffb21c8-libxl-dom0-state-fix.patch,
    e44bcae-virt-aa-helper-trailing-slash.patch,
    a55a5e7-virt-aa-helper-log.patch,
    61dab0f-virt-aa-helper-renaming.patch,
    24f3c2f-virt-aa-helper-fix-caps.patch,
    8dd8df6-qemu-cleanup-fix.patch, 4749fec-nbd-wait.patch
  - FATE#314466, FATE#314497, FATE#315157, FATE#318383
* Mon Jul 20 2015 ohering@suse.de
- Fix crash in libxl driver on receiving side
  0003-libxl-fix-ref-counting-of-libxlMigrationDstArgs.patch
  0004-libxl-don-t-attempt-to-resume-domain-when-suspend-fa.patch
  0005-libxl-acquire-a-job-when-receiving-a-migrating-domai.patch
  bsc#936185
- Refresh libxl-set-cach-mode.patch for xen-4.5
* Wed Jul 15 2015 cbosdonnat@suse.com
- Fixed virt-aa-helper bugs preventing virt-sandbox to work.
  24f3c2f-virt-aa-helper-fix-caps.patch
  61dab0f-virt-aa-helper-renaming.patch
  a55a5e7-virt-aa-helper-log.patch
  e44bcae-virt-aa-helper-trailing-slash.patch
  bsc#936841
- Fixed crasher due to uninitialized values.
  4749fec-nbd-wait.patch
  8dd8df6-qemu-cleanup-fix.patch
  bsc#936841
* Thu Jul  9 2015 jfehlig@suse.com
- libxl: set dom0 state to running
  4ffb21c8-libxl-dom0-state-fix.patch
  bsc#937316
* Tue Jul  7 2015 jfehlig@suse.com
- libxl: support management of dom0
  45697fe5-libxl-support-dom0.patch
  bsc#937316
- libxl: libxl: fix setting state of virDomainObj
  e9c27344-libxl-fix-virDomainObj-state.patch
  bsc#934937
* Thu Jul  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.17
  - parallels driver renamed to vz (Virtuozzo)
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - FATE#314466, FATE#314497, FATE#315157, FATE#318383
- spec: re-enable tests that have received upstream fixes and
  are now passing
* Thu Jun 11 2015 jfehlig@suse.com
- spec: remove guard around declaration of
  libvirtd-systemd-socket.patch
* Wed Jun  3 2015 jfehlig@suse.com
- Remove unsupported settings in libvirtd.socket unit file when
  systemd version < 214
  libvirtd-systemd-socket.patch
  bsc#933043
* Tue Jun  2 2015 jfehlig@suse.com
- Update to libvirt to 1.2.16
  - See http://libvirt.org/news.html for a list of features,
    enhancements, and bug fixes since version 1.2.5 found in
    SLE12
  - Drop upstream patches c0d3f608-libxl-soundhw.patch and
    8910e063-arch-caps.patch
  - Drop polkit-10-virt.rules in favor of upstream 50-libvirt.rules
  - FATE#314466, FATE#314497, FATE#315157, FATE#318383
* Tue Jun  2 2015 jfehlig@suse.com
- spec: fix building of rbd storage backend for x86
  FATE#318349
* Thu May 21 2015 jfehlig@suse.com
- Update to libvirt to 1.2.15
  - See http://libvirt.org/news.html for a list of features,
    enhancements, and bug fixes since version 1.2.5 found in
    SLE12
  - FATE#314466, FATE#314497, FATE#315157, FATE#318383
* Wed Apr 22 2015 cbosdonnat@suse.com
- Fixed apparmor generated profile for PCI hostdevs. bsc#921555
  virt-aa-helper-hotplug.patch
* Thu Mar 12 2015 jfehlig@suse.com
- Include additional upstream fixes for systemd TerminateMachine
  9661ac2f-qemu-unref-cfg.patch,
  b3e4401d-systemd-error-reporting.patch
  bnc#899334
* Tue Mar 10 2015 jfehlig@suse.com
- Fix security driver default settings in /etc/libvirt/qemu.conf
  Modified suse-qemu-conf.patch
  bsc#921586
* Mon Mar  9 2015 cbosdonnat@suse.com
- Fixed a number of QEMU apparmor abstraction problems. bsc#921355
  apparmor-fixes.patch
* Fri Feb  6 2015 cbosdonnat@suse.com
- bsc#911737: additionnal fix for the case where security labels
  aren't automatically set. a58e1cb4-container-cleanup.patch
* Wed Jan 28 2015 jfehlig@suse.com
- CVE-2015-0236: libvirt: access control bypass
  03c3c0c8-CVE-2015-0236.patch, b347c0c2-CVE-2015-0236.patch
  bsc#914693
* Thu Jan 22 2015 cbosdonnat@suse.com
- virt-create-rootfs: allow setting the URL of an SMT server to use
  in place of SCC. virt-create-rootfs.patch. bsc#914297
* Fri Jan 16 2015 cbosdonnat@suse.com
- Backported route definition changes. bsc#904432
  4b47b4dc-ipv6-regex.patch
  2fc7e4a2-network-route-definition-to-networkcommon.patch
  ca481a6f-move-network-route-code-to-networkcommon.patch
  a1176529-use-network-route-definitions-for-domains.patch
  3993c2f9-virSocketAddrGetIpPrefix-0-special-cases.patch
  57e681e5-domain_conf-resolve-Coverity-RESOURCE_LEAK.patch
  c6adccae-domain_conf-check-virSocketAddrFormat-errors.patch
* Mon Jan 12 2015 carnold@suse.com
- Fix build failure for test case securityselinuxlabeltest
  caf164f1-test-add-user_xattr-check.patch
* Thu Jan  8 2015 lmb@suse.com
- enable building with rbd on x86_64 (FATE#318349)
* Thu Jan  8 2015 mlatimer@suse.com
- Apparmor profile regression breaks Xen domains. bsc#913799
  b61fb8e8-apparmor-xen-fixup.patch
  338b07af-apparmor-allow-helpers.patch
  c0273cd6-apparmor-tck-raw-packets.patch
* Wed Jan  7 2015 cbosdonnat@suse.com
- Transformed Errors into warnings in detect_scsi_host_caps.
  bsc#891936.
  4039e22e-VIR_WARN-in-detect_scsi_host.patch
* Tue Jan  6 2015 cbosdonnat@suse.com
- Fix a missing cleanup for lxc containers.
  a58e1cb4-container-cleanup.patch. bsc#911737
- Renamed patches as they went upstream:
  - lxc-net-target-name.patch
  - > 3ba0469c-lxc-net-target-name.patch
  - lxc-net-target-name-conversion.patch
  - > 7c10a774-lxc-net-target-name-conversion.patch
  - lxc-keep-caps-feature.patch
  - > 47e5b5ae-lxc-keep-caps.patch
  - lxc-keep-caps-feature-conversion.patch
  - > 26d67015-lxc-keep-caps-conversion.patch
  - ifname_guest-cleanup.patch
  - > b11a75dc-ifname_guest-cleanup.patch
- Removed patches as merged into another when upstreaming:
  - lxc-net-target-name-doc.patch merged into
    3ba0469c-lxc-net-target-name.patch
  - lxc-keep-caps-feature-doc.patch merged into
    47e5b5ae-lxc-keep-caps.patch
- Adding network configuration to containers. bsc#904432
  4dc04d3a-virNetDevSetIPv4Address-libnl.patch
  2b0598c8-rename-virNetDevSetIPv4Address.patch
  9c9da602-virNetDevAddRoute-libnl.patch
  3c318dc9-virNetDevClearIPv4Address-libnl.patch
  c9ebdf9b-rename-virNetDevClearIPv4Address.patch
  69f7b67d-virSocketAddrNumericFamily.patch
  aa2cc721-domain-multiple-ips.patch
  ecdc9383-lxc-veth-set-ip.patch
  12a75f37-lxc-conf2xml-convert-ip-addresses.patch
  2811cc61-net-caps-hostdev-ips.patch
  7100be40-lxc-conf2xml-convert-hostdev-ips.patch
  c9a641f1-domain-routes.patch
  430e9391-lxc-conf2xml-gateway.patch
  cef6eb77-lxc-set-routes.patch
  bbf1eafa-lxc-honour-nic-state.patch
  e85df090-error-multiple-ips.patch
* Mon Jan  5 2015 cbosdonnat@suse.com
- Replaced hard to maintain install-apparmor-profiles.patch by
  upstream 30c6aecc-apparmor-profile-lib64.patch
* Mon Dec 22 2014 jfehlig@suse.com
- CVE-2014-8136: libvirt: local denial of service in qemu driver
  2bdcd29c-CVE-2014-8136.patch
  bsc#910862
* Sun Dec 14 2014 jfehlig@suse.com
- Fix segfault in fs storage driver
  Updated c110cdb2-fix-format-probe.patch
  bsc#909828
* Wed Dec 10 2014 cbosdonnat@suse.com
- Fix potential crasher in virt-aa-helper
  2222123-virt-aa-helper-crash.patch
- Fixes for virt-sandbox-service to work. bsc#909249:
  - Allow adding virt-sandbox service config to apparmor rules.
    c264eea-virt-aa-helper-sandbox.patch
  - fix symlink resolving for containers to start.
    72fecf1-lxc-resolve-symlinks.patch
  - fix unmounting file system if it contains the source to mount.
    e50457d-lxc-unmount-check.patch
  - Reworked the patch mounting ipv[46] folders RW to get rid of
    temporary mounts. sys-net-rw.patch
* Fri Dec  5 2014 jfehlig@suse.com
- qemu: allow setting migration max downtime any time
  fe808d95-qemu-mig-downtime.patch
  bsc#908590
* Fri Dec  5 2014 cbosdonnat@suse.com
- Fix mounting of /sys in containers, and ease maintenance by adding
  a86b6215-sysfs-userns-nonetns.patch. bsc#904432
* Mon Dec  1 2014 cbosdonnat@suse.com
- Get /proc/sys/net/ipv[46] read-write for wicked to work in
  containers. bsc#904432. sys-net-rw.patch
- Clean unfreed variable. ifname_guest-cleanup.patch
* Mon Nov 24 2014 jfehlig@suse.com
- libxl: several migration improvements
  cb88d433-libxl-mig-thread.patch, a1f38951-libxl-mig-job.patch,
  60386825-libxl-mig-start-paused.patch,
  42874fa4-libxl-mig-failure-cleanup.patch
  bsc#903756
- libxl: allow libxl to find pygrub binary
  d70a51d5-pygrub-path.patch
  bdo#770485
* Mon Nov 17 2014 cbosdonnat@suse.com
- Fix Qemu AppArmor abstraction.
  - qemu-block.so was denied on x86_64.
    install-apparmor-profiles.patch
  - Temporary fix access to screenshot temporary file. bsc#904426.
    qemu-apparmor-screenshot.patch
* Thu Nov 13 2014 jfehlig@suse.com
- Fix build when enabling with_dtrace
  Modified libvirt.spec
* Tue Nov 11 2014 jfehlig@suse.com
- CVE-2014-7823: dumpxml: security hole with migratable flag
  b1674ad5-CVE-2014-7823.patch
  bsc#904176
* Tue Oct 28 2014 cbosdonnat@suse.com
- AppArmor confined kvm domains couldn't find the apparmor profile
  template. apparmor-rework-fix.patch
  bnc#902976
* Sat Oct 11 2014 lma@suse.com
- backport commit c110cdb2 to fix non-raw storage format error
  c110cdb2-fix-format-probe.patch
  bnc#900587
* Thu Oct  2 2014 jfehlig@suse.com
- qemu: use systemd's TerminateMachine to kill all processes
  4882618-qemu-terminatemachine.patch
  bsc#899334
* Thu Oct  2 2014 jfehlig@suse.com
- CVE-2014-3657: Fix domain deadlock
  fc22b2e7-CVE-2014-3657.patch
  bsc#899484
* Tue Sep 23 2014 jfehlig@suse.com
- libvirt-guests: start after time-sync.target instead of
  ntp-wait.service as agreed upstream
  Replace libvirt-guests-wait-for-ntp.patch with upstream patch
  a9bad1a3-libvirt-guests-time-sync.patch
  bnc#895194
* Fri Sep 19 2014 jfehlig@suse.com
- libxl: Support user-specified emulator and keymap
  libxl-dev-model.patch, libxl-support-emulator.patch,
  libxl-support-keymap.patch
  bnc#897611
* Fri Sep 19 2014 jfehlig@suse.com
- libxl: Drop driver lock in libxlDomainDefineXML
  c7892373-libxl-remove-lock.patch
  bnc#897379
* Fri Sep 19 2014 jfehlig@suse.com
- CVE-2014-3633: Use correct definition when looking up disk in
  qemu blkiotune
  3e745e8f-CVE-2014-3633.patch
  bnc#897783
* Tue Sep 16 2014 jfehlig@suse.com
- libxl: Fix HVM direct kernel boot
  libxl-hvm-kernel-boot.patch
  bnc#896044
* Mon Sep 15 2014 jfehlig@suse.com
- Fix mapping of libvirt and libxl lifecycle events
  817206cd-libxl-lifecycle-events.patch
  bnc#896789
* Mon Sep  8 2014 jfehlig@suse.com
- Wait for ntp service before running libvirt-guests
  libvirt-guests-wait-for-ntp.patch
  bnc#895194
* Thu Sep  4 2014 jfehlig@suse.com
- Canonicalize host arch name ppc64le to ppc64
  ppc64le-canonical-name.patch
  bnc#894956
* Thu Sep  4 2014 cyliu@suse.com
- bnc#888166 - unix domain sockets for qemu chardev with
  insufficient permissions
  0e1a1a8c-qemu-ensure-sane-umask-for-qemu-process.patch
  e9f69374-util-don-t-shadow-global-umask-declaration.patch
* Fri Aug 29 2014 mlatimer@suse.com
- bnc#894232 - Update apparmor profile to allow raw packets
  install-apparmor-profiles.patch
* Tue Aug 26 2014 jfehlig@suse.com
- virsh: Fix initialization of vshData in cmdMigrate to avoid
  calling virConnectClose with uninitialized data
  c285ffc4-virsh-mig-initdata.patch
* Tue Aug 26 2014 jfehlig@suse.com
- libxl: Fix libvirtd crash triggered by some guest <graphics>
  configurations
  4dfc34c3-libxl-vnc-fix.patch
- Replace virsh-migration-hang.patch with upstream
  7eabd550-virsh-mig-hang.patch
* Wed Aug 20 2014 ro@suse.de
- remove not necessary hunks from libvirt-ppc64le-support.patch
- move new patches to section for to be upstreamed
* Tue Aug 19 2014 ro@suse.de
- add patch: libvirt-power8-models.patch
  add current power8 cpu models to map
* Tue Aug 19 2014 ro@suse.de
- add patch: libvirt-ppc64le-support.patch
  add preliminary ppc64le support to libvirt
* Fri Aug 15 2014 jfehlig@suse.com
- Fix apparent hang of 'virsh migrate' command
  virsh-migration-hang.patch
  bnc#886153
* Fri Aug  8 2014 cyliu@suse.com
- bnc#820399 - virsh blockcopy should refuse identical device
  blockcopy-check-dst-identical-device.patch
* Thu Aug  7 2014 jfehlig@suse.com
- libxl: Implement domainReset
  libxl-dom-reset.patch
  bnc#870170
* Wed Jul 30 2014 cbosdonnat@suse.com
- Added a patch to remove all mount rules in apparmor profile
  abstraction for lxc: those aren't supported by the kernel and
  cause YaST apparmor to fail. bnc#883060.
  apparmor-profile-no-mount.patch
- Domain configuration changed capabilities weren't written back if
  all features are set to default. bnc#889552.
  lxc-keep-caps-feature.patch
* Thu Jul 17 2014 cyliu@suse.com
- Update add-nocow-to-vol-xml.patch with upstream patch
  a9fd30e6-storagevol-add-nocow-to-vol-xml.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- Renamed virt-lxc-convert-fix.patch into
  dba3432b-virt-lxc-convert-fix.patch as it went upstream
* Wed Jul 16 2014 cbosdonnat@suse.com
- lxc AppArmor profile now only restricting potentially dangerous
  accesses. fdo#886460
- added patches:
  * 9265f8ab-apparmor-lxc-rework.patch
  * 9b1e4cd5-skip-useless-apparmor-files.patch
- modified patches:
  * install-apparmor-profiles.patch
* Tue Jul 15 2014 jfehlig@suse.com
- libxl: fixes for PCI/SR-IOV passthrough
  232cf2a4-libxl-hostdev-config.patch,
  b0d24540-libxl-iface-hostdev.patch,
  2f97ea32-libxl-hostdev-fix.patch
  bnc#887164
* Wed Jul  9 2014 jfehlig@suse.com
- libxl: migration improvements, particularly on error paths
  92cd6b67-libxl-label-rename.patch,
  c4f66bb8-libxl-mig-prepare.patch,
  bab7ad4c-libxl-mig-job-fix.patch,
  72a84539-libxl-mig-crash-fix.patch
  bnc#885808
* Fri Jul  4 2014 cbosdonnat@suse.com
- virt-lxc-convert: force free to output values in bytes
- added patches:
  * virt-lxc-convert-fix.patch
* Wed Jul  2 2014 jfehlig@suse.com
- Move 'Requires' of qemu from libvirt-daemon-qemu subpackage to
  libvirt-daemon-driver-qemu
  bnc#885267
* Wed Jul  2 2014 cbosdonnat@suse.com
- lxc: allow setting a custom name for container NICs as LXC is
  is able to do it.
  lxc-net-target-name.patch,
  lxc-net-target-name-conversion.patch,
  lxc-net-target-name-doc.patch
- lxc-keep-caps-feature.patch: updated to match the version approved
  by upstream
* Mon Jun 30 2014 jfehlig@suse.com
- libxl: detect support for save and restore, which is not
  supported on all architectures
  1d37a4c4-libxl-detect-save-restore.patch
* Mon Jun 30 2014 jfehlig@suse.com
- libxl: add PV console if not explicitly specified
  Fixes SLES11 -> SLES12 upgrades
  ec7b9225-libxl-pv-console.patch
* Tue Jun 24 2014 jfehlig@suse.com
- libxl: use qdisk instead of tapdisk backend when
  <driver name='file'/>.  Fixes SLES11 -> SLES12 upgrades.
  48d81cef-libxl-qdisk.patch
* Fri Jun 20 2014 jfehlig@suse.com
- libxl: Use cooperative resume for migration
  c1bc06e2-libxl-mig-resume-fix.patch
  Xen project bug#30: http://bugs.xenproject.org/xen/bug/30
* Thu Jun 19 2014 jfehlig@suse.com
- Fix conversion of xm config contain 'root='
  ac63014c-libxl-domxml-from-native.patch,
  64b60266-xmconfigtest-fix.patch
  bnc#875197
* Thu Jun 19 2014 jfehlig@suse.com
- Drop libxl-iface-network.patch and libxl-iface-script.patch.
  Replace with upstream equivalents:
  bf410bb8-libxl-iface-network.patch,
  2624dfde-libxl-iface-script.patch
* Wed Jun 18 2014 cbosdonnat@suse.com
- virt-lxc-convert.patch accepted upstream. Dropped and replaced
  with b73aafd6-virt-lxc-convert.patch
* Mon Jun 16 2014 cbosdonnat@suse.com
- lxc-keep-caps-feature.patch: allow to keep/drop additional
  capabilities for LXC containers. bnc#881465
- lxc-keep-caps-feature-conversion.patch: convert lxc.cap.drop to
  the new domain configuration.
- lxc-keep-caps-feature-doc.patch: documentation for the new feature.
* Fri Jun 13 2014 jfehlig@suse.com
- libxl: fix domxml-to-native with qemu disk driver
  libxl-domxml-to-native.patch
  bnc#875197
* Wed Jun 11 2014 jfehlig@suse.com
- libxl: support interface type=network
  libxl-iface-network.patch, libxl-iface-script.patch
  bnc#870525
* Tue Jun 10 2014 jfehlig@suse.com
- Remove unnecessary patches for the legacy Xen driver, which is
  not built for SLE12
  Dropped fix-pci-attach-xen-driver.patch, xen-name-for-devid.patch
* Tue Jun 10 2014 jfehlig@suse.com
- qemu: fix use of encrypted qcow2 disks
  1c7eb95c-qemu-encrypt-disk.patch
  bnc#881793
* Thu Jun  5 2014 jfehlig@suse.com
- Replace libxl-migration-support.patch with upstream equivalents
  d9a099a4-libxl-abi-check.patch and 9b8d6e1e-libxl-migration.patch
* Mon Jun  2 2014 cbosdonnat@suse.com
- virt-create-rootfs.patch: Add a script to help creating SLE and
  openSUSE rootfs. bnc#871885
* Mon Jun  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.5
  - Introduce virDomain{Get,Set}Time APIs
  - Introduce virDomainFSFreeze() and virDomainFSThaw() public API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches:
    1d98e713-sec-dac5.patch 292d3f2d-libselinux-build-fix1.patch,
    3c2487ab-sec-dac8.patch, 3de7e4ec-sec-dac6.patch,
    5099084e-sec-dac3.patch, 88e36a69-sec-dac11.patch,
    9369a562-sec-dac7.patch, 99f50208-managed-hostdev-iface.patch,
    a0f82fd2-sec-dac10.patch, b109c097-libselinux-build-fix2.patch,
    b98bf811-add-paravirt-shutdown-flag.patch, bb917a90-sec-dac9.patch,
    c4fe29f8-use-shutdown-flag.patch, d6b27d3e-CVE-2014-0179.patch,
    d77fa847-sec-dac2.patch, da744120-use-reboot-flag.patch,
    e1ce6d83-sec-dac4.patch. fcf5ea7f-sec-dac1.patch,
    fd43d1f8-libxl-iface-hostdev.patch
* Wed May 28 2014 jfehlig@suse.com
- Add upstream patches that fix build with libselinux 2.3
  Added: 292d3f2d-libselinux-build-fix1.patch,
    b109c097-libselinux-build-fix2.patch
  Dropped: libselinux-build-fix.patch
* Wed May 28 2014 cbosdonnat@suse.com
- Better fix for the libselinux 2.3 build breaker
  libselinux-build-fix.patch
* Wed May 28 2014 ohering@suse.de
- set cache= mode in libxl driver (unsafe|directsync)
  Added: libxl-set-cach-mode.patch
  bnc#879425
* Wed May 28 2014 ohering@suse.de
- Update discard support for libxl_device_disk to allow more values
  in overloaded ->readwrite member
  FATE#316071
* Tue May 27 2014 jfehlig@suse.com
- Fix build with libselinux 2.3
  selinux-build-fix-hack.patch
* Tue May 20 2014 jfehlig@suse.com
- spec: libvirt-daemon package owns /etc/libvirt, not libvirt-client
  bnc#878056
* Mon May 19 2014 jfehlig@suse.com
- DAC security driver: Fix crash with no seclables
  88e36a69-sec-dac11.patch
* Fri May 16 2014 jfehlig@suse.com
- spec: Drop useless ia64-clone.patch
* Fri May 16 2014 jfehlig@suse.com
- libxl: Add support for setting migration constraints
  libxl-set-migration-constraints.patch
  FATE#316614
* Fri May 16 2014 jfehlig@suse.com
- DAC security driver: honor relabel='no' attribute in device
  configuration
  * -sec-dac*.patch
  bnc#868189
* Mon May 12 2014 jfehlig@suse.com
- libxl: Fix <interface type='hostdev'> syntax for SR-IOV devices
  fd43d1f8-libxl-iface-hostdev.patch,
  99f50208-managed-hostdev-iface.patch
  FATE#313570
* Tue May  6 2014 jfehlig@suse.com
- Update to libvirt 1.2.4
  - Primarily a bug-fix release.  See http://libvirt.org/news.html
    for a detailed list of bug fixes and improvements
  - Drop upstream patches:
    0e0c1a74-domid-fix.patch, 7a1452f5-libxl-empty-cdrom.patch,
    lxcconf2xml-vpcus-fix.patch, drop-pm-utils.patch
- Renamed patches to include upstream commit id
  libxl-new-shutdown-flag.patch -> b98bf811-add-paravirt-shutdown-flag.patch
  libxl-use-shutdown-flag.patch -> c4fe29f8-use-shutdown-flag.patch
  libxl-use-reboot-flag.patch -> da744120-use-reboot-flag.patch
* Mon May  5 2014 jfehlig@suse.com
- CVE-2014-0179: Don't expand entities when parsing XML
  d6b27d3e-CVE-2014-0179.patch
  bnc#873705
* Fri May  2 2014 jfehlig@suse.com
- libxl: Support ACPI shutdown event
  libxl-new-shutdown-flag.patch, libxl-use-shutdown-flag.patch,
  libxl-use-reboot-flag.patch
  bnc#872777
- libx: Support migration
  libxl-migration-support.patch
  bnc#875193
* Tue Apr 22 2014 jfehlig@suse.com
- spec: Change libvirt-daemon-qemu subpackage to require qemu-kvm
  for x86_64 and s390x only.  For all other architectures, require
  qemu.  This ensures existing domains using
  <emulator>/usr/bin/qemu-kvm</emulator> continue to work, without
  burdening new architectures with a qemu-kvm dependency.
* Tue Apr  8 2014 jfehlig@suse.com
- libxl: Set disk format for empty cdrom device
  0e0c1a74-domid-fix.patch, 7a1452f5-libxl-empty-cdrom.patch
  bnc#872517
* Mon Apr  7 2014 cyliu@suse.com
- Fate#315125: add NOCOW flag
  add-nocow-to-vol-xml.patch
* Fri Apr  4 2014 cbosdonnat@suse.com
- lxc config conversion fixes:
  - updated virt-lxc-convert with new version submitted upstream
  - make virt-lxc-convert executable
  - the number of current vcpus can't be 0.
    added patch: lxcconf2xml-vpcus-fix.patch
  - virt-lxc-convert now fixes the rootfs of sles11 containers to
    properly start on sles12: lxc-convert-fix-sle11-rootfs.patch
* Wed Apr  2 2014 cbosdonnat@suse.com
- drop-pm-utils.patch: use systemd API instead of pm-is-supported.
  FATE: 316824. bnc#856381.
* Tue Apr  1 2014 jfehlig@suse.com
- Update to libvirt 1.2.3
  - add new virDomainCoreDumpWithFormat API
  - conf: Introduce virDomainDeviceGetInfo API
  - more features and fixes on bhyve driver
  - lot of cleanups and improvement on the Xen driver
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches:
    43c030f-lxc-apparmor.patch, a3e4eef-lxc-apparmor.patch,
    500b2e9-lxc-apparmor.patch, ef7dc7d-lxc-apparmor.patch,
    9194cce-lxc-apparmor.patch, f68246ac-libxl-sexpr.patch,
    apparmor-qemu-fix.patch, apparmor-vfio.patch,
    libxl-hvm-vnc.patch
  - FATES: 313213, 315155, 315468, 315423, 315429, 315430, 315431,
    315428, 315479, 315684, 315740, 315793, 316083, 316100, 316917
* Wed Mar 26 2014 cbosdonnat@suse.com
- Add virt-lxc-convert tool as a wrapper around virsh to ease
  conversion from LXC configuration to libvirt domain XML config.
  virt-lxc-convert.patch. fate#316917.
* Tue Mar 25 2014 cbosdonnat@suse.com
- Fix AppArmor profiles for qemu guests.
  apparmor-qemu-fix.patch: fixes a regression
  apparmor-vfio.patch: fix profile for vfio pci passthrough.
  lp#1276719
* Fri Mar 14 2014 jfehlig@suse.com
- Add /usr/sbin/rc{libvirtd,virtlockd,libvirt-guests} symlinks
  to preserve backwards compatibility
  bnc#868190
* Tue Mar 11 2014 jfehlig@suse.com
- libxl: support sexpr in native to XML conversion, providing
  another way to import legacy Xen configuration into libvirt
  f68246ac-libxl-sexpr.patch
* Fri Mar  7 2014 cbosdonnat@suse.com
- Implement securing LXC containers with AppArmor
  43c030f-lxc-apparmor.patch, 500b2e9-lxc-apparmor.patch
  9194cce-lxc-apparmor.patch, a3e4eef-lxc-apparmor.patch,
  ef7dc7d-lxc-apparmor.patch.
  bnc#863804
* Tue Mar  4 2014 jfehlig@suse.com
- Improve lock manager comments in qemu.conf
  Updated suse-qemu-conf.patch
* Tue Mar  4 2014 speilicke@suse.com
- Create /etc/libvirt/hooks to allow using hook scripts
* Mon Mar  3 2014 jfehlig@suse.com
- Update to libvirt 1.2.2
  - add LXC from native conversion tool
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - FATES: 313213, 315155, 315468, 315423, 315429, 315430, 315431,
    315428, 315479, 315684, 315740, 315793, 316083, 316100
  - bnc#857490
* Fri Feb 28 2014 jfehlig@suse.com
- libvirtd: notify systemd when ready to accept connections
  bnc#866233
* Wed Feb 26 2014 jfehlig@suse.com
- Update to libvirt 1.2.2 RC2
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    4f20084-fix-apparmor-install-path.patch
    Add-util-virCgroupGetBlkioIo-Serviced-methods.patch
    Implement-domainMemoryStats-API-slot-for-LXC-driver.patch
    Make-qemuGetDomainTotalCPUStats-a-virCgroup-function.patch
    Implement-domainGetCPUStats-for-lxc-driver.patch
    Implemet-lxcDomainBlockStats-for-lxc-driver.patch
    Widening-API-change-accept-empty-path-for-virDomainB.patch
    Implement-lxcDomainBlockStatsFlags-for-lxc-driver.patch
  - Add local disable-virCgroupGetPercpuStats-test.patch to disable
    failing virCgroupGetPercpuStats test in 'make check'
  - FATES: 313213, 315155, 315468, 315423, 315429, 315430, 315431,
    315428, 315479, 315684, 315740, 315793, 316083, 316100
* Mon Feb 24 2014 jfehlig@suse.com
- daemon-qemu: Require qemu-kvm instead of kvm to align with
  recent changes to the qemu package structure
  bnc#865578
* Fri Feb 14 2014 jfehlig@suse.com
- spec: fix dependencies of daemon-config-network and
  daemon-config-nwfilter subpackages.  Influenced by upstream
  commits cf76c4b3 and dca5ce4c
* Fri Feb 14 2014 jfehlig@suse.com
- Remove libvirtd, virtlockd, and libvirt-guests init scripts when
  using systemd
  bnc#863540
* Wed Feb 12 2014 cbosdonnat@suse.com
- Fix the path to libvirtd AppArmor template profile:
  4f20084-fix-apparmor-install-path.patch
* Mon Feb 10 2014 dmueller@suse.com
- disable virnetsockettest: Unstable under test environment
* Wed Feb  5 2014 jfehlig@suse.com
- Add discard support to libxl_device_disk in libxl driver
  FATE#316071
* Wed Feb  5 2014 jfehlig@suse.com
- Explicitly disable hypervisor drivers not supported in SLES12
* Thu Jan 23 2014 tbehrens@suse.com
- Fate#313213 extend lxc monitoring features:
  * add Add-util-virCgroupGetBlkioIo-Serviced-methods.patch
  * add Implement-domainGetCPUStats-for-lxc-driver.patch
  * add Implement-domainMemoryStats-API-slot-for-LXC-driver.patch
  * add Implement-lxcDomainBlockStatsFlags-for-lxc-driver.patch
  * add Implemet-lxcDomainBlockStats-for-lxc-driver.patch
  * add Make-qemuGetDomainTotalCPUStats-a-virCgroup-function.patch
  * add Widening-API-change-accept-empty-path-for-virDomainB.patch
* Wed Jan 22 2014 jfehlig@suse.com
- Add CAP_SYS_PACCT capability to libvirtd AppArmor profile
  Modified install-apparmor-profiles.patch
  bnc#817407
* Wed Jan 22 2014 jfehlig@suse.com
- Following the upstream pattern, introduce the
  daemon-config-network subpackage to handle defining the default
  network
  bnc#859041
* Fri Jan 17 2014 jfehlig@suse.com
- Update to libvirt 1.2.1
  - CVE-2014-0028, CVE-2014-1447, CVE-2013-6458, CVE-2013-6457,
    CVE-2013-6436
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches: 5e397d9c-test-fix-dbus-crash.patch,
    78af457e-fix-virnettlscontexttest.patch,
    9faf3f29-LXC-memtune.patch, f8c1cb90-CVE-2013-6436.patch,
    libxl-hvm-nic.patch
  - FATES: 315155, 315468, 315423, 315429, 315430, 315431, 315428,
    315479, 315684, 315740, 315793, 316083, 316100
* Fri Dec 27 2013 jfehlig@suse.com
- Ignore 'make check' on older, code 11 base
* Thu Dec 26 2013 cbosdonnat@suse.com
- Fixed and reenabled unit tests. bnc#854694
* Fri Dec 20 2013 jfehlig@suse.com
- Remove dependency on pm-utils from libvirt-client
  bnc#856381
* Fri Dec 20 2013 jfehlig@suse.com
- CVE-2013-6436: Fix crashes in lxc memtune code, one of which
  results in DoS
  f8c1cb90-CVE-2013-6436.patch, 9faf3f29-LXC-memtune.patch
  bnc#854486
* Fri Dec  6 2013 jfehlig@suse.com
- More adjustments to the spec file to fix package dependency
  issues
  bnc#848918
* Fri Dec  6 2013 jfehlig@suse.com
- Update to libvirt 1.2.0
  - Add support for gluster pool
  - Separation of python binding
  - vbox: add support for 4.3 APIs
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Updated and renamed clone.patch to ia64-clone.patch
- Enabled numad support for openSUSE >= 13.1
* Wed Dec  4 2013 jfehlig@suse.com
- Link with same versions of libnl used by netcontrol to prevent
  crashing libvirtd on start
* Wed Dec  4 2013 jfehlig@suse.com
- Add '/etc/sasl2' to libvirt-client file list to fix Factory build
* Wed Nov 27 2013 jfehlig@suse.com
- Fix starting of libvirtd when NetworkManager is enabled
  Modified libvirt-suse-netcontrol.patch
* Tue Nov 26 2013 jfehlig@suse.com
- Allow execution of libvirt hook scripts in /etc/libvirt/hooks/
  in libvirtd AppArmor profile
* Wed Nov 20 2013 jfehlig@suse.com
- Update to libvirt 1.1.4
  - Add support for AArch64 architecture
  - Various improvements on test code and test driver
  - Don't link virt-login-shell against libvirt.so
  - Close all non-stdio FDs in virt-login-shell
  - Only allow 'stderr' log output when running setuid
  - Fix perms for virConnectDomainXML{To,From}Native
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: e7f400a1-CVE-2013-4296.patch,
    2dba0323-CVE-2013-4297.patch, db7a5688-CVE-2013-4311.patch,
    e65667c0-CVE-2013-4311.patch, 922b7fda-CVE-2013-4311.patch,
    e4697b92-CVE-2013-4311.patch, 8294aa0c-CVE-2013-4399.patch,
    484cc321-fix-spice-migration.patch,
    79552754-libvirtd-chardev-crash.patch,
    57687fd6-CVE-2013-4401.patch, ae53e5d1-CVE-2013-4400.patch,
    8c3586ea-CVE-2013-4400.patch, b7fcc799a-CVE-2013-4400.patch,
    3e2f27e1-CVE-2013-4400.patch, 5a0ea4b7-CVE-2013-4400.patch,
    843bdb2f-CVE-2013-4400.patch,
    bd773e74-lxc-terminate-machine.patch,
    e350826c-python-fix-fd-passing.patch
* Tue Nov 19 2013 jfehlig@suse.com
- Allow execution of Xen binaries in /usr/lib{,64}/xen/bin in
  libvirtd AppArmor profile
  bnc#849524
* Tue Nov 19 2013 jfehlig@suse.com
- Require libvirt-daemon-<hypervisor> in the main libvirt package
  for each supported hypervisor
  bnc#850882
* Mon Nov  4 2013 jfehlig@suse.com
- Fix initialization of libxl NIC devices
  libxl-hvm-nic.patch
  bnc#848918
* Wed Oct 30 2013 jfehlig@suse.com
- Fix typo in libvirtd apparmor profile which prevented the profile
  from loading
  bnc#848216
* Fri Oct 25 2013 jfehlig@suse.com
- libxl driver: fix initialization of VNC and SDL info for
  HVM domains
  libxl-hvm-vnc.patch
  bnc#847566
- Allow libvirtd apparmor profile to access /etc/xen/scripts/*
* Wed Oct 23 2013 jfehlig@suse.com
- Fix file descriptor passing in python bindings
  e350826c-python-fix-fd-passing.patch
  rhb#1021434
* Tue Oct 22 2013 cbosdonnat@suse.com
- Have systemd terminate the machine as a workaround of fdo#68370
  bd773e74-lxc-terminate-machine.patch
  bnc#842834
* Tue Oct 22 2013 jfehlig@suse.com
- Spec file fixes to only package libvirt-login-shell when
  building the LXC driver
* Mon Oct 21 2013 jfehlig@suse.com
- CVE-2013-4400: Unsantized use of env variables allows privilege
  escalation via virt-login-shell
  ae53e5d1-CVE-2013-4400.patch, 8c3586ea-CVE-2013-4400.patch,
  b7fcc799a-CVE-2013-4400.patch, 3e2f27e1-CVE-2013-4400.patch,
  5a0ea4b7-CVE-2013-4400.patch, 843bdb2f-CVE-2013-4400.patch
  bnc#837609
- CVE-2013-4401: Fix perms for virConnectDomainXML{To,From}Native
  57687fd6-CVE-2013-4401.patch
  bnc#845704
* Fri Oct 18 2013 jfehlig@suse.com
- Move hypervisor-specific files out of libvirt-daemon package
  and into libvirt-daemon-<hypervisor> subpackage
  bnc#845851
- conf: Don't crash on invalid chardev source definition
  79552754-libvirtd-chardev-crash.patch
  bnc#845704, rhb#1012196
* Thu Oct 17 2013 jfehlig@suse.com
- Use newer libnl3 instead of libnl-1_1
  bnc#845540
* Tue Oct 15 2013 jfehlig@suse.com
- Move virt-login-shell to new subpackage libvirt-login-shell,
  requiring users to opt-in for this setuid binary.  Note: For now,
  virt-login-shell will not have setuid permissions, pending
  resolution of bnc#837609
* Tue Oct 15 2013 jfehlig@suse.com
- qemu: Fix seamless SPICE migration
  484cc321-fix-spice-migration.patch
  bnc#842301
* Tue Oct 15 2013 jfehlig@suse.com
- CVE-2013-4399: Fix crash in libvirtd when events are registered
  and ACLs active
  8294aa0c-CVE-2013-4399.patch
  bnc#844052, bnc#842300
* Mon Oct 14 2013 jfehlig@suse.com
- Update the stale gettext BuildRequires and Requires dependencies
  in the spec file
  bnc#841325
* Mon Oct 14 2013 jfehlig@suse.com
- virt-aa-helper apparmor profile was denying read access to
  /proc/$PID/*.  Give read accesss to these files.
  Updated install-apparmor-profiles.patch
  bnc#841720
* Mon Oct 14 2013 jfehlig@suse.com
- libvirtd apparmor profile was denying access to
  /usr/lib/xen/bin/qemu-system-i386, which is now the default
  emulator used with Xen guests
  Updated install-apparmor-profiles.patch
  bnc#845648
* Thu Oct  3 2013 jfehlig@suse.com
- Fix condrestart|try-restart invocation of virtlockd init script
  Modifed virtlockd-init-script.patch
* Tue Sep 17 2013 jfehlig@suse.com
- CVE-2013-4311: Add support for using 3-arg pkcheck syntax for
  process
  db7a5688-CVE-2013-4311.patch, e65667c0-CVE-2013-4311.patch,
  922b7fda-CVE-2013-4311.patch, e4697b92-CVE-2013-4311.patch
  bnc#836931
* Thu Sep  5 2013 jfehlig@suse.com
- CVE-2013-4296: Fix crash in remoteDispatchDomainMemoryStats
  e7f400a1-CVE-2013-4296.patch
  bnc#838638
- CVE-2013-4297: Fix crash in virFileNBDDeviceAssociate
  2dba0323-CVE-2013-4297.patch
  bnc#838642
* Tue Sep  3 2013 jfehlig@suse.com
- Update to libvirt 1.1.2
  - various improvements to libxl driver
  - systemd integration improvements
  - Add flag to BaselineCPU API to return detailed CPU features
  - Introduce a virt-login-shell binary
  - conf: add startupPolicy attribute for harddisk
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: bcef0f01-libxl-console.patch,
    9d0557b9-legacy-xen-double-free.patch,
    d7a45bf2-legacy-xen-dumpxml.patch, 0e671a16-CVE-2013-4239.patch
  - Includes fixes for bnc#837530, bnc#837531, bnc#837999
* Tue Aug 13 2013 jfehlig@suse.com
- Fix memory corruption in legacy Xen driver
  0e671a16-CVE-2013-4239.patch
  bnc#834598
- Upstream patches to fix dumpxml in legacy Xen driver
  9d0557b9-legacy-xen-double-free.patch,
  d7a45bf2-legacy-xen-dumpxml.patch
* Wed Jul 31 2013 jfehlig@suse.com
- Backport upstream patch implementing domainOpenConsole in the
  libxl driver.  Allows 'virsh console dom-name' to work with
  Xen libxl toolstack.
  bcef0f01-libxl-console.patch
* Tue Jul 30 2013 jfehlig@suse.com
- Update to libvirt 1.1.1
  - Adding device removal or deletion events
  - Introduce new domain create APIs to pass pre-opened FDs to LXC
  - Add interface versions for Xen 4.3
  - Add new public API virDomainSetMemoryStatsPeriod
  - Various LXC improvements
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: f38c8185-CVE-2013-2230.patch,
    fd2e3c4c-xen-sysctl-domctl.patch, dfc69235-CVE-2013-4153.patch,
    96518d43-CVE-2013-4154.patch, fe89fd3b-storage-pool-deadlock.patch
  - Drop relax-qemu-usergroup-check.patch - no longer needed
    after hypervisor-specific daemon package split
* Mon Jul 22 2013 jfehlig@suse.com
- Unlock the storage volume object after looking it up
  fe89fd3b-storage-pool-deadlock.patch
  rhb#980676
* Mon Jul 22 2013 jfehlig@suse.com
- CVE-2013-4153: Fix double free of returned JSON array in
  qemuAgentGetVCPUs()
  dfc69235-CVE-2013-4153.patch
- CVE-2013-4154: Prevent crash of libvirtd without guest agent
  configuration
  96518d43-CVE-2013-4154.patch
  bnc#830498
* Wed Jul 17 2013 jfehlig@suse.com
- Fix legacy xen driver with Xen 4.3
  fd2e3c4c-xen-sysctl-domctl.patch
* Wed Jul 10 2013 jfehlig@suse.com
- CVE-2013-2230: Fix crash when multiple event callbacks were
  registered
  f38c8185-CVE-2013-2230.patch
  bnc#827801
* Wed Jul 10 2013 jfehlig@suse.com
- Update to libvirt 1.1.0
  - Extensible migration APIs
  - Add a policy kit access control driver
  - various improvements in the Xen and libxl drivers
  - improve networking support on BSD
  - agent based vCPU hotplug support
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 244e0b8c-CVE-2013-2218.patch
* Mon Jul  8 2013 jfehlig@suse.com
- Only require lzop if suse_version > 1210
* Wed Jul  3 2013 jfehlig@suse.com
- Fix typo in spec file
* Wed Jul  3 2013 jfehlig@suse.com
- Enable support for netcontrol by default
- Only require libvirt-daemon-driver-interface when building the
  interface driver
* Mon Jul  1 2013 jfehlig@suse.com
- CVE-2013-2218: Fix crash listing network interfaces with filters
  244e0b8c-CVE-2013-2218.patch
* Tue Jun 11 2013 jfehlig@suse.com
- Add xencommons as 'Wanted' in the systemd libvirtd service file
  systemd-service-xen.patch
  bnc#820888
* Mon Jun 10 2013 jfehlig@suse.com
- Fix build for SLE11 SP2
* Fri Jun  7 2013 jfehlig@suse.com
- Add a README to the empty packages.  Provides some info about
  their purpose and satisfies suse-filelist-empty check.
  Drop rpmlintrc
* Fri Jun  7 2013 jfehlig@suse.com
- Fix typo in spec file: devel package requires doc package, not
  docs
* Thu Jun  6 2013 jfehlig@suse.com
- Add rpmlintrc to get around suse-filelist-empty error on
  older distros.
* Thu Jun  6 2013 jfehlig@suse.com
- Refactor libvirt spec file to create subpackages for the various
  libvirtd components.  This allows installing a libvirtd tailored
  for the underlying virtualizer.  E.g. on a KVM/QEMU virtualizer
  only the libvirt-daemon-qemu package needs installed.
  Similarly, only libvirt-daemon-xen on a Xen virtualizer and
  libvirt-daemon-lxc on LXC.
* Tue Jun  4 2013 jfehlig@suse.com
- Update to libvirt 1.0.6
  - Move VirtualBox driver into libvirtd
  - Support for static routes on a virtual bridge
  - Various improvement for hostdev SCSI support
  - Switch to VIR_STRDUP and VIR_STRNDUP
  - Various cleanups and improvement in Xen and LXC drivers
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: f493d83f-cgroup-swap-control.patch,
    486a86eb-cgroups-docs.patch, 0ced83dc-cgroup-escape-dot.patch,
    bbe97ae9-no-cgroups.patch, c2cf5f1c-no-cgroups-fix.patch,
    95c6cc34-selinux.patch
* Tue May 21 2013 jfehlig@suse.com
- Update to libvirt 1.0.5.1 stable release
  - qemu: Fix cgroup handling when setting VCPU BW
  - daemon: fix leak after listing all volumes
  - Fix iohelper usage with streams opened for read
  - util: fix virFileOpenAs return value and resulting error logs
  - iscsi: don't leak portal string when starting a pool
  - don't mention disk controllers in generic controller errors
  - conf: don't crash on a tpm device with no backends
  - qemu: allocate network connections sooner during domain startup
  - Make detect_scsi_host_caps a function on all architectures
  - Fix release of resources with lockd plugin
  - Fix potential use of undefined variable in remote dispatch code
  - Fix F_DUPFD_CLOEXEC operation args
  - qemu: fix stupid typos in VFIO cgroup setup/teardown
  - network: fix network driver startup for qemu:///session
- Remove patches that are included in the 1.0.5.1 release
  0471637d-cgroups-vcpu-bw.patch, a2214c52-iohelper.patch,
  ca697e90-CVE-2013-1962.patch
* Mon May 20 2013 jfehlig@suse.com
- Don't mount selinux fs in LXC if selinux is disabled
  95c6cc34-selinux.patch
  bnc#814680
* Sat May 18 2013 jfehlig@suse.com
- fix leak after listing all volumes - CVE-2013-1962
  ca697e90-CVE-2013-1962.patch
  bnc#820397
- Fix iohelper usage with streams opened for read
  a2214c52-iohelper.patch
- Cope with missing swap cgroup controls
  f493d83f-cgroup-swap-control.patch
  bnc#819976
- Fix cgroup handling when setting VCPU BW
  0471637d-cgroups-vcpu-bw.patch
  rhb#963592
- Escape a leading '.' with '_' in the cgroup names
  0ced83dc-cgroup-escape-dot.patch
- Add missing documentation on new cgroup layout
  486a86eb-cgroups-docs.patch
- Another fix related to systems with no cgroups
  c2cf5f1c-no-cgroups-fix.patch
  bnc#819963
* Thu May 16 2013 jfehlig@suse.com
- Fix botched backport of commit bbe97ae9
* Mon May 13 2013 jfehlig@suse.com
- Fix starting domains when kernel has no cgroups support
  bbe97ae9-no-cgroups.patch
* Thu May  2 2013 jfehlig@suse.com
- Update to libvirt 1.0.5
  - PPC64: Add NVRAM device
  - Add XML config for resource partitions
  - Add support for TPM
  - NPIV storage migration support
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Tue Apr  2 2013 jfehlig@suse.com
- Update to libvirt 1.0.4
  - qemu: support passthrough for iscsi disks
  - various S390 improvements
  - various LXC bugs fixes and improvements
  - add API for thread cancellation
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: ce4557c3-apparmor-tapfd-label.patch
    libvirt-iptables-1.4.18.diff
* Sun Mar 24 2013 seife+obs@b1-systems.com
- add libvirt-iptables-1.4.18.diff, fix masquerading with iptables
  v1.4.18 (--state match is deprectated, use conntrack instead)
* Fri Mar  8 2013 jfehlig@suse.com
- Fix PCI device attach for xen HVM domains
  fix-pci-attach-xen-driver.patch
  FATE#313570
* Fri Mar  8 2013 jfehlig@suse.com
- Apparmor security driver: Ensure tapfd's are labled when
  generating the guest profile.
  Modified install-apparmor-profiles.patch, added upstream patch
  ce4557c3-apparmor-tapfd-label.patch
  bnc#807940
* Thu Mar  7 2013 jfehlig@suse.com
- Grant permission to use datagram packets in libvirtd apparmor
  profile.
  Remove AF_PACKET.patch, modify install-apparmor-profiles.patch
  bnc#801145
* Wed Mar  6 2013 jfehlig@suse.com
- Add 'managed' PCI passthrough support to legacy xen driver
  support-managed-pci-xen-driver.patch
  FATE#313570
* Tue Mar  5 2013 jfehlig@suse.com
- Update to libvirt 1.0.3
  - Introduce virDomainMigrate*CompressionCache APIs
  - Introduce virDomainGetJobStats API
  - Add basic support for VDI images
  - Introduce API virNodeDeviceLookupSCSIHostByWWN
  - Various locking improvements
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: a6b8bae5-python-generator-fix1.patch,
    25ea8e47-python-generator-fix2.patch,
    567779e5-libxl-default-disk-backend.patch
* Fri Mar  1 2013 jfehlig@suse.com
- Fix path to qemu-bridge-helper in libvirt-qemu apparmor profile
  Modified install-apparmor-profiles.patch
* Mon Feb 25 2013 jfehlig@suse.com
- Fix detach of managed PCI devices from inactive domains.
  Detected while running test cases for FATE #313570.
  Modified xen-name-for-devid.patch
* Thu Feb 21 2013 jfehlig@suse.com
- spec: Fix installation of default network
* Wed Feb 20 2013 jfehlig@suse.com
- Fix default setting of backend field of libxl_device_disk
  567779e5-libxl-default-disk-backend.patch
  rhb#912488
* Tue Feb 12 2013 jfehlig@suse.com
- Fix build on IA64
  Modified clone.patch
* Thu Feb  7 2013 jfehlig@suse.com
- Fix error handling in python bindings
  a6b8bae5-python-generator-fix1.patch
  25ea8e47-python-generator-fix2.patch
  bnc#802619
* Sun Feb  3 2013 crrodriguez@opensuse.org
- Require modutils instead of module-init-tools.
* Wed Jan 30 2013 jfehlig@suse.com
- Update to libvirt 1.0.2
  - LXC improvements
  - S390 architecture improvements
  - Power architecture improvements
  - large Coverity report cleanups and associated bug fixes
  - virTypedParams* APIs to help with those data structures
  - libxenlight driver improvements
  - Fixes CVE-2013-0170, bnc#800976
  - Drop upstream patches: 68e7bc45-libxl-link-fix.patch,
    462a6962-script-fixes1.patch, cb854b8f-script-fixes2.patch,
    5ec4b22b-script-fixes3.patch, a1fd56cb-script-fixes4.patch,
    66ff2ddc-virtlockd-systemd-file-perms.patch
* Tue Jan 22 2013 jfehlig@suse.com
- Unconditionally build sanlock support
  bnc#799262
* Tue Jan 22 2013 jfehlig@suse.com
- Fix interface management functions that were broken when
  rebasing libvirt-suse-netcontrol.patch
  bnc#799444 (SLES bug that affect Factory too)
* Sat Jan  5 2013 jfehlig@suse.com
- Update to libvirt 1.0.1
  - Introduce virtlockd daemon
  - parallels: add disk and network device support
  - Add virDomainSendProcessSignal API
  - Introduce virDomainFSTrim() public API
  - add fuse support for libvirt lxc
  - Add Gluster protocol as supported network disk backend
  - various snapshot improvements
- Add upstream patches to fix bugs in 1.0.1
  66ff2ddc-virtlockd-systemd-file-perms.patch,
  462a6962-script-fixes1.patch, cb854b8f-script-fixes2.patch,
  5ec4b22b-script-fixes3.patch, a1fd56cb-script-fixes4.patch,
  68e7bc45-libxl-link-fix.patch
- Rework SUSE patches for the various init scripts
  Dropped use-init-script-redhat.patch and added
  libvirtd-init-script.patch, libvirt-guests-init-script.patch,
  and virtlockd-init-script.patch
* Fri Nov  2 2012 jfehlig@suse.com
- Update to libvirt 1.0.0
  - virNodeGetCPUMap: Define public API
  - Add systemd journal support
  - Add a qemu capabilities cache manager
  - USB migration support
  - various improvement and fixes when using QMP QEmu interface
  - Support for Xen 4.2 in legacy xen driver
  - Lot of localization enhancements
  - Drop upstream patches: 371ddc98-xen-sysctl-9.patch,
    416eca18-xenstore-header-fix.patch,
    f644361b-virCommand-env.patch, 2b32735a-virCommand-env.patch,
    9785f2b6-fix-xen-sysctl9.patch
* Tue Oct 23 2012 jfehlig@suse.com
- Fix Xen sysctl version 9 support
  9785f2b6-fix-xen-sysctl9.patch
* Thu Oct 11 2012 jfehlig@suse.com
- Add upstream patches to support latest libguestfs
  f644361b-virCommand-env.patch
  2b32735a-virCommand-env.patch
* Thu Sep 27 2012 jfehlig@suse.com
- Fix build when using -werror
  416eca18-xenstore-header-fix.patch
* Wed Sep 26 2012 jfehlig@suse.com
- Support Xen sysctl version 9
  371ddc98-xen-sysctl-9.patch
  bnc#781425
* Tue Sep 25 2012 jfehlig@suse.com
- Temporarily disable building libxl driver.  The current
  implementation does not support libxl in Xen 4.2.
* Tue Sep 25 2012 jfehlig@suse.com
- Update to libvirt 0.10.2
  - network: define new API virNetworkUpdate
  - add support for QEmu sandbox support
  - blockjob: add virDomainBlockCommit
  - node_memory: Define the APIs to get/set memory parameters
  - list: Define new API virConnectListAllSecrets
  - list: Define new API virConnectListAllNWFilter
  - list: Define new API virConnectListAllNodeDevices
  - list: Define new API virConnectListAllInterfaces
  - list: Define new API virConnectListAllNetworks
  - list: Define new API virStoragePoolListAllVolumes
  - list: Define new API virStorageListAllStoragePools
  - parallels: add support of containers to the driver
  - Add PMSUSPENDED life cycle event
  - Add per-guest S3/S4 state configuration
  - qemu: Support for Block Device IO Limits
* Fri Sep  7 2012 jfehlig@suse.com
- Update to libvirt 0.10.1
  - Bug fix release for critical bugs in 0.10.0
  - Drop upstream patch f781e276-xen-driver-fix.patch
* Fri Aug 31 2012 jfehlig@suse.com
- Update to libvirt 0.10.0
  - agent: add qemuAgentArbitraryCommand()
  - Introduce virDomainPinEmulator and virDomainGetEmulatorPinInfo
  - network: use firewalld instead of iptables, when available
  - network: make network driver vlan-aware
  - esx: Implement network driver
  - driver for parallels hypervisor
  - Various LXC improvements
  - Add virDomainGetHostname
  - Drop upstream patches
    4036aa91-systemd.patch
    6039a2cb-CVE-2012-3445.patch
* Fri Aug 31 2012 jfehlig@suse.com
- Fix xen driver following changes to make it stateful
  f781e276-xen-driver-fix.patch
  bnc#778006
* Wed Aug  8 2012 jfehlig@suse.com
- Update to libvirt 0.9.13
  - S390: support for s390(x)
  - snapshot: implement new APIs for esx and vbox
  - snapshot: new query APIs and many improvements
  - virsh: Allow users to reedit rejected XML
  - nwfilter: add DHCP snooping
  - storage backend: Add RBD (RADOS Block Device) support
  - sVirt support for LXC domains inprovement
  - Drop upstream patches
    0dda594d-libvirtd-shutdown-deadlock.patch
    9c77bf04-fix-virnetserver-refcnt.patch
    57349ffc-lxc-ctrl.patch
    revert-d8978c90.patch
* Tue Aug  7 2012 jfehlig@suse.com
  _ Update to libvirt 0.9.12
  - qemu: allow snapshotting of sheepdog and rbd disks
  - blockjob: add new AP
  - many bug fixes and improvements
* Wed Aug  1 2012 jfehlig@suse.com
- daemon: Fix crash in virTypedParameterArrayClear
  CVE-2012-3445
  6039a2cb-CVE-2012-3445.patch
  bnc#773955
* Tue Jul 10 2012 jfehlig@suse.com
- libvirtd.service: ensure libvirtd starts after network
  4036aa91-systemd.patch
  bnc#767932
* Fri Jun 22 2012 jfehlig@suse.com
- Add upstream patch to fix ref count of virNetServer object
  9c77bf04-fix-virnetserver-refcnt.patch
* Thu Jun 21 2012 jfehlig@suse.com
- Fix libvirtd deadlock on shutdown
  0dda594d-libvirtd-shutdown-deadlock.patch
  bnc#767797
* Thu Jun 21 2012 jfehlig@suse.com
- Fix segfault in libvirt_lxc
  57349ffc-lxc-ctrl.patch
  bnc#767448
* Wed Jun 20 2012 jfehlig@suse.com
- Fix build on i586
  revert-d8978c90.patch
* Tue Jun 19 2012 jfehlig@suse.com
- Update to libvirt 0.9.11.4 stable release
* Tue Jun 12 2012 jfehlig@suse.com
- VUL-1: Fix hotplug support for usb devices with same vendorID,
  productID
  9914477e-usb-search-funcs.patch
  05abd150-usb-improve-hotplug.patch
  bnc#766559
* Wed May 30 2012 jfehlig@suse.com
- Add capability 'audit_write' to libvirtd apparmor profile
  update install-apparmor-profiles.patch
  bnc#764388
- Update to libvirt 0.9.11.3 stable release
* Wed Apr 25 2012 jfehlig@suse.com
- Copy user in virURIParse
  4eb1c256-viruri-user.patch
  bnc#757766
* Wed Apr 25 2012 jfehlig@suse.com
- yajl is availabile in all supported SUSE products, so always
  use it when building libvirtd
* Thu Apr 12 2012 jfehlig@suse.com
- Update to libvirt 0.9.11
  - Add support for the suspend event
  - Add support for event tray moved of removable disks
  - qemu: Support numad
  - cpustats: API, improvements and qemu support
  - qemu: support type='hostdev' network devices at domain start
  - Introduce virDomainPMWakeup API
  - network: support Open vSwitch
  - snapshot improvements
* Mon Mar 26 2012 jfehlig@suse.com
- Remove unconditional define of 'with_netcontrol'
* Thu Feb 16 2012 jfehlig@suse.com
- Add a note in /etc/libvirt/qemu.conf describing administrator
  vigilance required when enabling a lock manager such as sanlock
* Thu Feb 16 2012 jfehlig@suse.com
- Recommend dmidecode if suse_version > 1110.  dmidecode is used
  by virConnectGetSysinfo.
* Thu Feb 16 2012 jfehlig@suse.com
- Add upstream patches to fix issues with older PolicyKit
  c05ec920-polkit0-build.patch
  fcdfa31f-polkit0-auth.patch
* Wed Feb 15 2012 jfehlig@suse.com
- Update to libvirt 0.9.10
  - Add support for sVirt in the LXC driver
  - Add new API virDomainBlockRebase
  - Add api to set and get domain metadata
  - virDomainGetDiskErrors public API
  - Add rawio attribute to disk element of domain XML
  - Introduce virDomainPMSuspendForDuration API
  - Add virStorageVolResize() API
  - Add a virt-host-validate command to sanity check HV config
  - Add new virDomainShutdownFlags API
  - QEMU guest agent support
* Wed Feb  8 2012 jfehlig@suse.com
- Fix libvirtd apparmor profile to work with libxenlight toolstack
  Updated install-apparmor-profiles.patch
  bnc#745890
* Wed Jan 25 2012 jfehlig@suse.com
- Fix init script packaging after enabling systemd support
* Tue Jan 24 2012 jfehlig@suse.com
- Fix %%files after enabling sanlock support
* Wed Jan 18 2012 jfehlig@suse.com
- Enable libvirt integration with sanlock
* Wed Jan 11 2012 jfehlig@suse.com
- During configure, libvirt checks for availability of iptables
  binary and doesn't actually use anything from iptables-devel
  package, hence only need 'BuildRequires: iptables'.
* Mon Jan  9 2012 jfehlig@suse.com
- Update to libvirt 0.9.9
  - Add new API virDomain{S,G}etInterfaceParameters
  - Add new API virDomain{G,S}etNumaParameters
  - Add support for ppc64 qemu
  - Support Xen domctl v8
* Wed Jan  4 2012 jfehlig@suse.com
- Fixup systemd support as per openSUSE systemd packaging
  guidelines.
* Tue Jan  3 2012 jfehlig@suse.com
- Use %%fdupes for duplicate file checking instead of hand-rolled
  function
* Thu Dec 15 2011 jfehlig@suse.com
- CVE-2011-4600: unintended firewall port exposure after restarting
  libvirtd when defining a bridged forward-mode network
  ae1232b2-CVE-2011-4600.patch
  bnc#736082
- Post-0.9.8 upstream systemd patches
  10404671-systemd-build-fix.patch 478a4d07-systemd-build-fix.patch
- Update to libvirt 0.9.8
  - Add support for QEMU 1.0
  - Add first parts of PPC cpu driver
  - Add new API virDomain{Set, Get}BlockIoTune
  - block_resize: Define the new API
  - Add a public API to invoke suspend/resume on the host
  - Various improvements for LXC containers
  - Define keepalive protocol and add virConnectIsAlive API
  - Add support for STP and VLANfiltering
  - Numerous bug fixes and improvements
* Wed Dec 14 2011 jfehlig@suse.com
- Add support for QEMU 1.0
  dd8e8956-qemu-1.0.patch
  bnc#736569
* Wed Nov 30 2011 jfehlig@suse.com
- Allow qemu driver (and hence libvirtd) to load when qemu
  user:group does not exist.  The kvm or qemu package, which may
  not exist on a xen host, creates qemu user:group.
  relax-qemu-usergroup-check.patch
* Mon Nov 28 2011 jfehlig@suse.com
- Handle empty strings in s-expression returned by xend
  a495365d-sexpr-empty-str.patch
  bnc#731344
- Allow libvirtd to access libvirt_{io,part}helper when confined
  by apparmor
  Update install-apparmor-profiles.patch
  bnc#730435
* Mon Nov 21 2011 jfehlig@suse.com
- Accommodate Xen domctl version 8
  xen-domctl-ver8.patch
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Nov 15 2011 jfehlig@suse.com
- Fix build when using older PolicyKit
  d47ab3fe-polkit0.patch
* Thu Nov 10 2011 jfehlig@suse.com
- Update to libvirt 0.9.7
  - esx: support vSphere 5.x
  - vbox: support for VirtualBox 4.1
  - Introduce the virDomainOpenGraphics API
  - Add AHCI support to qemu driver
  - snapshot: many improvements and 2 new APIs
  - api: Add public api for 'reset'
* Tue Oct 18 2011 jfehlig@suse.com
- Add AHCI controller support to qemu driver
  c1bc3d89-qemu-add-ahci.patch
- Set security driver to 'none' in /etc/libvirt/qemu.conf.  Users
  must opt-in for Apparmor confinement of qemu instances.
  suse-qemu-conf.patch
* Fri Sep 23 2011 jfehlig@suse.com
- Revert upstream commit f84aedad, which is not needed since
  affected SUSE kvm packages have the necessary qemu fix
  f84aedad-revert.patch
* Fri Sep 23 2011 jfehlig@suse.com
- Update to libvirt 0.9.6
  - Fix shutdown regression with buggy qemu
* Wed Sep 21 2011 andrea.turrini@gmail.com
- Fixed typos in libvirt.spec
* Tue Sep 20 2011 jfehlig@suse.com
- Update to libvirt 0.9.5
  - many snapshot improvements
  - latency: Define new public API and structure
  - USB2 and various USB improvements
  - storage: Add fs pool formatting
  - Add public API for getting migration speed
  - Add basic driver for Microsoft Hyper-V
  - Many bug fixes and improvements
* Fri Sep 16 2011 jfehlig@suse.com
- Enable building with libnetcontrol
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Wed Sep 14 2011 jfehlig@suse.com
- Set qemu migration speed unlimited when migrating to file
  7e5f6a51-rpc-generator.patch b12354be-mig-speed-1.patch
  1282bd80-mig-speed-2.patch 6f84e110-mig-speed-3.patch
  829bce17-mig-speed-4.patch 8fc40c51-mig-speed-5.patch
  ef1065cf-mig-speed-6.patch 0257ba8f-mig-speed-7.patch
  bnc#706436
* Wed Sep 14 2011 jfehlig@suse.com
- Increase max size of buffer used to receive xend response
  57c95175-xend-buff-size.patch
- Don't overwrite useful error messages in legacy xen driver
  32620dab-fix-xen-err-msg.patch
  bnc#711096
* Wed Sep 14 2011 jfehlig@suse.com
- Add upstream patches to stop excessive logging
  7f2498ef-no-log-invalid.patch 6ff9fc26-quiet-libxl-logging.patch
* Wed Sep 14 2011 jfehlig@suse.com
- Add 'Conflicts: kvm < 0.14.1' to ensure libvirt is using a
  kvm package that creates qemu user:group.  Remove user:group
  creation from libvirt
  bnc#694883
- Add libvirt group at package installation
  bnc#694885
* Thu Sep  8 2011 jfehlig@suse.com
- Explicitly add 'BuildRequires: libgcrypt-devel' since it is no
  longer required by libgnutls-devel
* Thu Sep  8 2011 jfehlig@suse.com
- netcf is buggy and not well maintained in SUSE.  Disable it in
  libvirt
* Thu Sep  8 2011 jfehlig@suse.com
- polkit support was mistakenly disabled, re-enable
* Thu Aug 25 2011 jfehlig@novell.com
- Add cgconfig to Should-{Start,Stop} in libvirtd init script
  bnc#712245
* Fri Aug 19 2011 jfehlig@suse.com
- Fix apparmor profile location and content
  update install-apparmor-profiles.patch
  bnc#705668
* Wed Aug 17 2011 jfehlig@suse.com
- Fix libvirtd SIGHUP handler
  9e093f0b-libvirtd-sighup.patch
* Wed Aug 17 2011 dmueller@suse.de
- add baselibs.conf to sources
* Mon Aug  8 2011 jfehlig@suse.com
- Enable apparmor security dirver, SLES bnc#705668
  install-apparmor-profiles.patch
* Thu Aug  4 2011 jfehlig@suse.com
- Update to libvirt 0.9.4
  - bandwidth QoS control
  - Add new API virDomainBlockPull*
  - save: new API to manipulate save file images
  - CPU bandwidth limits support
  - allow to send NMI and key event to guests
  - new API virDomainUndefineFlags
  - Implement code to attach to external QEMU instances
  - various missing python binding
  - bios: Add support for SGA
  - Numerous improvements and documentation / bug fixes
* Wed Jul 13 2011 jfehlig@suse.de
- Add some upstream patches to fix memory leaks and some bugs
  in new rpc code
  c2ddd536-cert-key-order.patch 3e5d48ef-rpc-1.patch
  927dfcf6-rpc-2.patch 2c85644b-rpc-3.patch afe8839f-rpc-4.patch
  3cfdc57b-rpc-5.patch 7518ad75-remote-mem-leak.patch
  a34e193f-statstest.patch 41828514-skip-xen-tests.patch
  eb314315-pv-kernel-cmdline.patch 00d3c5a6-remove-dead-code.patch
  b8adfcc6-fix-polkit0-build.patch b2534529-unused-param.patch
* Tue Jul  5 2011 jfehlig@suse.de
- Update to libvirt 0.9.3
  - vcpupin: introduce the new libvirt API (virDomainGetVcpupinInfo)
  - Add TXT record support for virtual DNS service
  - Support reboots with the QEMU driver
  - Introduce virDomainGetControlInfo API
  - virNodeGetMemoryStats: Expose new API
  - virNodeGetCPUTime: Implement public API
  - send-key: Defining the public API
  - vcpupin: introduce a new libvirt API (virDomainPinVcpuFlags)
  - support multifunction PCI device
  - lxc: various improvements
* Fri Jul  1 2011 jfehlig@suse.de
- Create qemu user:group if necessary at package installation.
  More fallout from bnc#694883
* Thu Jun 30 2011 jfehlig@suse.de
- VUL-0: libvirt: integer overflow in VirDomainGetVcpus
  774b21c1-CVE-2011-2511.patch
  bnc#703084
* Thu Jun 30 2011 jfehlig@suse.de
- Enable building libvirt with audit support
  bnc#694891
* Mon Jun 13 2011 lidongyang@novell.com
- fate#311371 Enhance yast to configure live migration for
  Xen and KVM
  add firewall service file for libvirt
* Thu Jun  9 2011 jfehlig@suse.de
- Invoke qemu instances as user:group qemu:qemu by default
  bnc#694883
* Mon Jun  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.2
  - Framework for lock manager plugins
  - API for network config change transactions (netcf required)
  - flags for setting memory parameters
  - virDomainGetState public API
  - qemu: allow blkstat/blkinfo calls during migration
  - Introduce migration v3 API
  - Defining the Screenshot public API
  - public API for NMI injection
- spec file: Adjust some directory attributes to support running
  non-privileged qemu instances
* Sun May 15 2011 jfehlig@suse.de
- Remove vi_VN locale if suse_version < 11.3
* Thu May 12 2011 fcrozat@suse.com
- Enable cap_ng when building lxc support.
* Fri May  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.1
  - support various persistent domain updates
  - improvements on memory APIs
  - Add virDomainEventRebootNew
  - various improvements to libxl drive
  - Spice: support audio, images and stream compression
* Tue Apr 12 2011 jfehlig@suse.de
- Move libvirt-iohelper from client to base package
* Tue Apr 12 2011 coolo@opensuse.org
- fix baselibs.conf not to requires source 32bit
* Mon Apr 11 2011 jfehlig@suse.de
- Install log dir for libxl
  f7e9b448-libxl-build.patch
* Mon Apr  4 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 final
  - Support cpu usage tuning
  - Add public APIs for storage volume upload/download
  - Add public API for setting migration speed on the fly
  - Add libxenlight driver
  - qemu: support migration to fd
  - add virDomain{Get,Set}BlkioParameters
  - introduce a new libvirt API (virDomainSetMemoryFlags)
  - Expose event loop implementation as a public API
  - Dump the debug buffer to libvirtd.log on fatal signal
  - Audit support
  - Numerous enhancements and bug fixes
* Thu Mar 31 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 RC3
* Thu Mar 24 2011 coolo@novell.com
- use %%first_lang before changing symlinks, find_lang removes
  unsupported languages
* Tue Mar 15 2011 jfehlig@novell.com
- VUL-0: libvirt: several API calls do not honour read-only
  connection
  71753cb7-CVE-2011-1146.patch
  bnc#678406
* Mon Mar  7 2011 jfehlig@novell.com
- Add baselibs.conf file to build xxbit packages
  for multilib support
  bnc#676921
* Fri Feb 25 2011 jfehlig@novell.com
- Minor fixes for libvirt-guests
  bnc#653398
* Fri Feb 18 2011 jfehlig@novell.com
- Do not add drive 'boot=on' param when a kernel is specified
  efc2594b-boot-param.patch
* Thu Feb 17 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 final
  - sysinfo: expose new API
  - cgroup blkio weight support
  - smartcard device support
  - qemu: Support per-device boot ordering
* Tue Feb 15 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC3
* Fri Feb 11 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC1
* Mon Jan 31 2011 jfehlig@novell.com
- Remove explicit dependency on libyajl
  libvirt.spec
  bnc#668225
* Fri Jan 21 2011 jfehlig@novell.com
- Retry JSON monitor 'cont' cmd on MigrationExpected error
  4301b95a-json-cont-cmd.patch
* Tue Jan 18 2011 jfehlig@novell.com
- Add support for specifying Hardware Assisted Paging (HAP) in
  libvirt domain XML.
  48a5dccd-hap1.patch
  04197350-hap2.patch
  af521a01-hap3.patch
  79f56c66-hap4.patch
  094c6f4a-hap-fix.patch
  bnc#659665
* Tue Jan 18 2011 jfehlig@novell.com
- Enabled yajl for suse_version >= 1140
* Fri Jan 14 2011 jfehlig@novell.com
- Fix generation of dnsmasq's --dhcp-hostsfile option
  a43c7338-dnsmasq-hostfile-fix.patch
- Disable yajl support as the library does not yet exist in
  SuSE distros.
* Tue Jan 11 2011 jfehlig@novell.com
- Support libvirt-guests on SuSE distros
  use-libvirt-guests-on-suse.patch
  bnc#653398
* Mon Jan  3 2011 jfehlig@novell.com
- Update to libvirt 0.8.7
  - Preliminary support for VirtualBox 4.0
  - IPv6 support
  - Add VMware Workstation and Player driver
  - Add network disk support
* Wed Dec 22 2010 jfehlig@novell.com
- Fix VNC port reservation race in qemu driver
  c58b1056-init-bitmap-size.patch
  bnc#659431
* Fri Dec 10 2010 jfehlig@novell.com
- Do not limit insserv_cleanup to SLES
* Thu Dec  9 2010 jfehlig@novell.com
- disable building openvz driver
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.6
  - new API virDomainIsUpdated
  - Add support for iSCSI target auto-discovery
  - QED: Basic support for QED images
  - Introduce a virDomainOpenConsole API
  - Support for SPICE graphics
  - Add a sysinfo and SMBIOS support
  - Implement virsh qemu-monitor-command
- Enabled yajl, macvtap, and virtualport for suse_version >= 1140
* Mon Nov  1 2010 jfehlig@novell.com
- Fix build when using "policy kit 0"
  polkit0.patch
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.5
  - Enable JSON and netdev features in QEMU > 0.13
  - framework for auditing integration
  - framework for DTrace/SystemTap integration
  - Setting the number of vcpu at boot
  - Enable support for nested SVM
  - Virtio plan9fs filesystem QEMU
  - Memory parameter controls
  - portability to OS-X
  - lot of bug fixes and other improvements
* Wed Oct 13 2010 jfehlig@novell.com
- cannot restart dead libvirtd without manually removing pidfile
  modified libvirtd.init
  bnc#645755
* Mon Oct 11 2010 cristian.rodriguez@opensuse.org
- Fix package dependencies so can be installed without
  pulling excess of optional components
* Tue Oct  5 2010 cristian.rodriguez@opensuse.org
- Support dropping capabilities with cap-ng library in
  openSUSE >= 11.3
* Tue Sep 28 2010 jfehlig@novell.com
- Fix build when virtualport support is available but macvtap is
  disabled.
  vport-configure.patch
* Thu Sep 23 2010 jfehlig@novell.com
- Fix CDROM media change for Xen PV domains
  modified xen-pv-cdrom.patch
  bnc#636231
* Fri Sep 10 2010 jfehlig@novell.com
- Update to libvirt 0.8.4
  - various improvements to UML driver
  - documentation improvements
  - lot of bug fixes and other improvements
  - enable ESX driver for openSUSE
* Sat Aug  7 2010 jfehlig@novell.com
- Update to libvirt 0.8.3
  - Support vSphere 4.1
  - Qemu arbitrary monitor commands
  - Qemu Monitor API entry point
  - lots of improvements and bug fixes
* Fri Jul  9 2010 jfehlig@novell.com
- VUL-0: multiple issues in libvirt
  CVE-2010-223x-000[1-0].patch, CVE-2010-223x-0010.patch,
  CVE-2010-2242-nat.patch
  bnc#618155
* Fri Jun 25 2010 jfehlig@novell.com
- Use netcat-openbsd, which contains a proper 'nc' program
  supporting the '-U' option.  Drop socat.patch.
  bnc#611023
* Mon Jun 21 2010 jfehlig@novell.com
- Re-enable numa support now that bnc#598488 is resolved.
* Fri Jun  4 2010 jfehlig@novell.com
- Allocate buffer to hold xend content
  bnc#609738
  xend-buff-size.patch
- Add upstream fixes to bitmap code that was introduced to fix
  bnc#594024
  bitmap-alloc.patch
  bitmap-fixes.patch
* Tue Jun  1 2010 jfehlig@novell.com
- Fix race in VNC port reservation with qemu/KVM domains
  bnc#594024
  vnc-race-{1,2,3}.patch
* Wed May 12 2010 jfehlig@novell.com
- Don't package directories/files under /var/run
- Add upstream commit 34a7f3f6 to fix unintentional breakage of
  RPC protocol.
- Disable numa support in openSUSE11.3/Factory pending resolution
  of bnc#598488
* Fri Apr 30 2010 jfehlig@novell.com
- Update to libvirt 0.8.1
  - Add virDomainGetBlockInfo API to query disk sizing
  - Start dnsmasq from libvirtd with --dhcp-hostsfile option
  - lots of improvements and bug fixes
* Tue Apr 13 2010 jfehlig@novell.com
- Update to libvirt 0.8.0
  - Snapshot API framework
  - Add managed save API entry points
  - Timer subselection for domain clock
  - Add hook utilities
  - Network filtering API
  - Introduce a new virDomainUpdateDeviceFlags public API
  - Introduce a new public API for domain events
  - Public virDomainMigrateSetMaxDowntime API
  - Add public API for volume wiping
  - xenapi: Initial commit of the new driver
  - lots of improvements and bug fixes
* Fri Mar 26 2010 jfehlig@novell.com
- Fix 'virsh dominfo' crash when no security driver is configured
  fix-no-secdriver.patch
* Mon Mar 22 2010 jfehlig@novell.com
- Updated to version 0.7.7
  - Introduce public API for domain async job handling
  - macvtap support
  - Add QEMU support for virtio channel
  - Add persistence of PCI addresses to QEMU
  - Functions for computing baseline CPU from a set of host CPUs
  - Public API for virDomain{Attach,Detach}DeviceFlags
  - lots of improvements and bug fixes
* Tue Mar  9 2010 jfehlig@novell.com
- Ensure yast-created bridges are not manipulated by libvirt
  bnc#584757
  Modified suse-network.patch
* Thu Mar  4 2010 jfehlig@novell.com
- Fix ordering of xen disks to preserve 'bootable' flag
  bnc#474738
  xend-disk-order.patch
- Add support for blktap2 disks
  xen-tap2-support.patch
* Mon Mar  1 2010 jfehlig@novell.com
- Fix listing of yast-created bridges
  bnc#583754
  Modified suse-network.patch
* Mon Feb 22 2010 jfehlig@novell.com
- Add support for new XEN_DOMCTL_INTERFACE_VERSION version 7.
  xen-domctl-ver7.patch
* Mon Feb 15 2010 jfehlig@novell.com
- Unconditionally add /var/log/libvirt/{qemu,lxc,uml} directories.
  bnc#579522
* Thu Feb  4 2010 jfehlig@novell.com
- Updated to version 0.7.6
  - Implement support for multi IQN
  - Implement CPU topology support for QEMU driver
  - Use QEmu new device adressing when possible
  - Implement SCSI controller hotplug/unplug for QEMU
  - lots of improvements and bug fixes
* Thu Jan 28 2010 jfehlig@novell.com
- Support new XEN_SYSCTL_INTERFACE_VERSION 7 in libvirt
  bnc#574124
  xen-sysctl-v7.patch
- Add upstream patches as prelude to fixing various device
  attach/detach issues
  devflag-0[1-9].patch
- Fix attaching/detaching disk device from inactive Xen guest
  bnc#500586 and bnc#573748
* Tue Jan 12 2010 jfehlig@novell.com
- Fix migration with Xen4.0
  bnc#569598
  Add xen-migration-params.patch
  Remove migrate-params.patch
* Thu Jan  7 2010 jfehlig@novell.com
- Fix freeing of uninitialized pointer when using HAL in
  node device driver
  node-dev-free.patch
* Mon Jan  4 2010 jfehlig@novell.com
- Require virt-utils package for common tools such as qemu-img
* Tue Dec 29 2009 jfehlig@novell.com
- Updated to version 0.7.5
  - Add new API virDomainMemoryStats to header and drivers
  - Public API and domain extension for CPU flags
  - expose SR IOV physical/virtual function relationships
  - Support for JSON mode monitor [deactivated]
  - Support for interface model='netfront'
  - vbox: Add support for version 3.1
  - Support QEMU's virtual FAT block device driver
  - lots of improvements and bug fixes
- Fix libvirt xen hypervisor driver to work with domctl interface
  version 6
  xen-shr-pages.patch
* Mon Dec  7 2009 jfehlig@novell.com
- Plumb domain description in xend backend
  xend-description-tag.patch
* Wed Nov 25 2009 jfehlig@novell.com
- Fix listing of defined but inactive Xen domains
  xen-list-defined.patch
* Tue Nov 24 2009 jfehlig@novell.com
- Updated to version 0.7.4
  - Implement a node device backend using libudev
  - New APIs for checking some object properties
  - Fully asynchronous monitor I/O processing
  - add MAC address based port filtering to qemu
  - support for IPv6 / multiple addresses per interfaces
  - lots of improvements and bug fixes
* Thu Nov 19 2009 jfehlig@novell.com
- Fix compilation against xen-unstable
  xen-max-vcpus.patch
- Modify detach-disk.patch as per upstream suggestions
* Thu Nov  5 2009 jfehlig@novell.com
- spec file: Fix polkit vs PolicyKit Requires
* Mon Oct 19 2009 jfehlig@novell.com
- Fix compilation when selinux is enabled
  selinux-ldflags.patch
- Fix compilation warnings
  updated snapshots.patch
  virsh-warning.patch
* Fri Oct 16 2009 jfehlig@novell.com
- Updated to version 0.7.2
  - sVirt AppArmor security driver
  - Add public API definition for data stream handling
  - ESX add esxDomainDefineXML()
  - LXC: suspend/resume support
  - Big code tree cleanup
  - Lots of bug fixes and improvements
* Tue Oct 13 2009 jfehlig@novell.com
- Add ocfs2 to list of supported fs pool types
  fate#307387
* Tue Oct 13 2009 jfehlig@novell.com
- Build phyp driver ifarch ppc64
  fate#307096
- Fix memory leaks in libvirtd's message processing
  msg-proc-memleak.patch
* Tue Sep 29 2009 jfehlig@novell.com
- Fix connection ref counting in xen drivers
  xen-refcnt.patch
* Fri Sep 25 2009 jfehlig@novell.com
- Fix abort in virsh when specifying a connection URI
  vshdeinit-recurse.patch
* Wed Sep 23 2009 jfehlig@novell.com
- Workaround for missing pkgconfig file in device-mapper-devel
  devmap-no-pkgconfig.patch
  bnc#540942
* Mon Sep 21 2009 jfehlig@novell.com
- Updated to version 0.7.1
  - Add support for encrypted (qcow) volume creation
  - Secret manipulation public API
  - Multipath storage support module
  - VBox add Storage Volume support
  - Support configuration of huge pages in guests
  - Support new PolicyKit 1.0 API
  - Compressed save image format for Qemu
  - Qemu add host PCI device hotplug support
* Wed Aug 26 2009 jfehlig@novell.com
- Updated to version 0.7.0
  - Interface implementation based on netcf (disabled on SuSE)
  - Add new net filesystem glusterfs
  - Initial VMWare ESX driver
  - Add support for VBox 3 and event callbacks on vbox
  - First version of the Power Hypervisor driver
  - Run QEMU guests as an unprivileged user (still root on SuSE)
  - Support cgroups in QEMU driver
  - QEmu hotplug NIC support
  - Storage cloning for LVM and Disk backends
* Tue Jul  7 2009 jfehlig@novell.com
- Updated to version 0.6.5
  - create storage volumes on disk backend
  - drop of capabilities based on libcap-ng when possible
  - forbid autostart on transcient networks
  - re-detection of transient VMs after libvirtd restart
  - create and destroy NPIV support
  - other bug fixes and cleanups
* Fri Apr 24 2009 jfehlig@novell.com
- Removed unnecessary call to fillup_and_insserv macro in
  %%post scriptlet
* Wed Apr 22 2009 jfehlig@novell.com
- Updated to version 0.6.2
  - support SASL auth for VNC server
  - memory ballooning in QEMU
  - SCSI HBA storage pool support
  - PCI passthrough in Xen driver
  - new APIs for Node device detach reattach and reset
  - sVirt mandatory access control support
  - thread safety of the API and event handling
  - allow QEmu domains to survive daemon restart
  - extended logging capabilities
  - support copy-on-write storage volumes
  - support of storage cache control options for QEMU/KVM
- Improvements from lnussel@suse.de
  - add %%jobs macro again
  - package default qemu network and augeas config files again
  - don't start libvirtd by default (bnc#496838)
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of just removing static libraries
* Fri Jan 30 2009 jfehlig@novell.com
- Fix build for architectures not supporting numa
- Forward port suse-network.patch and snapshots.patch
* Wed Jan 28 2009 jfehlig@novell.com
- Updated to version 0.5.1
  - CPU and scheduler support for LXC
  - SDL display configuration
  - domain lifecycle event support for QEmu and Xen with python
    bindings
  - KVM/QEmu migration support
  - User Mode Linux driver
  - API for node device enumeration using HAL and DeviceKit with
    python bindings
  - Many bug fixes and improvements
* Fri Jan  9 2009 jfehlig@novell.com
- Added missing html and png files to libvirt-doc package
  devhelp.patch
  bnc#463810
* Mon Dec 15 2008 jfehlig@novell.com
- Patch for CVE-2008-5086
  bnc#459009
* Fri Dec  5 2008 jfehlig@novell.com
- Fix migration of Xen domains
  bnc#456946
* Tue Dec  2 2008 jfehlig@novell.com
- Refresh xen-maxmem.patch to match upstream
  bnc#431766
* Tue Nov 25 2008 jfehlig@novell.com
- Add network to Required-Start in libvirtd init script
  bnc#448756
* Mon Nov 24 2008 jfehlig@novell.com
- Fix connecting/disconnecting ISO via virt-manager
  bnc#446773
* Fri Nov 21 2008 jfehlig@novell.com
- Fix detach of Xen tap devices
  bnc#410644 and bnc#411633
* Fri Nov  7 2008 jfehlig@novell.com
- Fix handling of iso/cdrom for xen pv domains.
  bnc#437388
* Wed Nov  5 2008 jfehlig@novell.com
- Expose networks managed outside of libvirt as read-only.
  bnc#441633
* Wed Nov  5 2008 jfehlig@novell.com
- Fix vnc port assignement in domain XML
  bnc#441625
* Thu Oct 23 2008 jfehlig@novell.com
- Add upstream patches to fix ordering problem with setting up
  cgroup containment on LXC domains.
  bnc#437816
* Mon Oct 20 2008 jfehlig@novell.com
- Remove IA64 from list of architectures supporting Xen.
* Fri Oct 10 2008 jfehlig@novell.com
- Added upstream patches providing additional LXC support
  bnc#433881
* Mon Oct  6 2008 jfehlig@novell.com
- Use xend vs hypercall interface to change max mem setting
  bnc#431766
* Wed Oct  1 2008 jfehlig@novell.com
- Enabled libvirtd listen mode in libvirtd init script.
* Wed Oct  1 2008 jfehlig@novell.com
- Updated to version 0.4.6
  - avoid a segfault if missing qemu emulator
  - reading vncdisplay from xend domain
  - segfault in OpenVZ
  - fix parsing of pool without a source
- Fixed bug in network interface parsing
  - vif-parsing.patch submitted upstream
* Tue Sep 16 2008 jfehlig@novell.com
- open-iscsi package required for iscsi storage backend
* Mon Sep 15 2008 jfehlig@novell.com
- Updated to version 0.4.5
  - NETNS support for Linux containers
  - unified XML domain and network parsing for all drivers
  - OpenVZ features improvements
  - OpenVZ and Linux containers support now default
  - USB device passthrough for QEmu/KVM
  - storage pool source discovery
  - other bug fixes and improvements
* Thu Sep  4 2008 kwolf@suse.de
- Added Python bindings for the snapshot functions
* Wed Sep  3 2008 kwolf@suse.de
- Implemented listing of snapshots for Xen and in virsh
* Tue Sep  2 2008 kwolf@suse.de
- Added snapshot support. Implemented snapshot_create/apply/delete
  for Xen.
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in nfs storage pool creation/deletion
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in LVM storage pool creation.
  logical-storage-driver.patch submitted upstream
* Wed Aug 27 2008 jfehlig@novell.com
- Changed mDNS advertisement of libvirtd service to disabled by
  default.  Enable in libvirtd.conf.
- Disable libvirtd from listening on TLS socket by default.  User
  must enable after setting up CA and issuing certificates.
* Mon Aug 25 2008 jfehlig@novell.com
- Enabled iscsi storage driver support
- Enabled ssh transport using socat.  SuSE's version of netcat
  does not support connecting to UDS.
- Fixed spec file breakage due to SELinux enablement
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Tue Aug 12 2008 jfehlig@novell.com
- Cleanup of libvirtd init script
- Removed dnsmasq from BuildRequires
* Sat Aug  9 2008 jfehlig@novell.com
- Adjustments to spec file
  + Added /var/lib/libvirt directory
  + Enabled LXC support if suse_version > 1100, fate #304001
  + Cleaned up some rpmlint warnings
* Sun Jul  6 2008 jfehlig@novell.com
- Updated to libvirt 0.4.4
  + Bug fixes: QEmu network serialization, internal memory allocation
    fixes, virsh large file config problem, xen list APIs when max is
    zero, string escape problems in the xm driver
  + Improvements: add autogen to tarballs, improve iSCSI support
  + Cleanups: const-ness fixed, string helpers for enumeations
- spec file adjustments
  + Remove ExclusiveArch
  + Common spec file for all products
  + Support for building/running without Xen
* Fri May  9 2008 jfehlig@novell.com
- Adjust libvirtd PolicyKit configuration file to match standard
  suse procedures.  bnc#388769
* Mon May  5 2008 jfehlig@novell.com
- Fix path to iptables.  bnc#386280
* Thu Apr 24 2008 jfehlig@novell.com
- Fix Xen 3.2 hypercalls.  bnc#378798
* Thu Apr 10 2008 jfehlig@novell.com
- Fix NULL pointer dereference in auth callback.  bnc#373180,
  bnc#354995
* Wed Jan  9 2008 jfehlig@novell.com
- Remove Requires of nc package.  netcat is the equivalent but it
  does not support unix domain sockets so no need to require it
  either.
* Tue Jan  8 2008 coolo@suse.de
- do not require a non existant package, but change it to a recommend
  to digestmd5
* Fri Jan  4 2008 jfehlig@novell.com
- Updated to libvirt-0.4.0
  - SASL based authentication for libvirt remote support
  - PolicyKit authentication
  - Documentation: example files for QEMU and libvirtd configuations,
    authentication documentation updates
  - Bug fixes, improvements and code cleanup
* Tue Oct  9 2007 jfehlig@novell.com
- Updated to libvirt 0.3.3
  - Avahi mDNS daemon export
  - NUMA support
  - Bug fixes
- Cleanup rpmlint warnings
* Mon Oct  8 2007 jfehlig@novell.com
- Removed 'jobs' option from make invocation in spec file.  Appears
  to be a subtle dependency issue in one of the makefiles which is
  causing problems with generation of python bindings when jobs > 1.
  Bug #329032.
* Mon Aug 20 2007 jfehlig@novell.com
- Added init script for libvirtd.  libvirtd is needed to support
  management of qemu/kvm guests.  Some Xen networking is handled
  through libvirt as well - bug #298021.
* Mon Jul 23 2007 jfehlig@novell.com
- Update to libvirt-0.3.0
  - Secure Remote support
  - Documentation: remote support, description of the URI connection
    strings, update of virsh man page, matrix of libvirt API/hypervisor
    support with version informations
  - Bug fixes: examples Makefile.am generation, SetMem fix, URI
    handling and ordering of drivers, fix virsh help without hypervisor,
    id marshalling fix, fix virConnectGetMaxVcpus on remote, avoid
    a realloc leak, scheduler parameters handling for Xen, various
    early remote bug fixes, remove virsh leaks of domains references,
    configCache refill bug, fix XML serialization bugs
  - Improvements: QEmu switch to XDR-based protocol, device attach/detach
    commands OCaml bindings, new entry points virDomainGetConnect and
    virNetworkGetConnect useful for bindings, reunitifaction of remote
    and qemu daemon under a single libvirtd with a config file
  - Cleanups: parsing of connection URIs, messages from virsh,
    Coverage files, Solaris fixes, avoid [r]index calls, release
    information in Xen backend, virsh cpupin command cleanups,
    xen:/// suppport as standard Xen URI, improve driver
    selection/decline mechanism, error reporting on XML dump,
    Remove unused virDomainKernel structure, daemon event loop event
    handling, various unifications cleanup in the daemon merging,
    internal file and timer monitoring API, remove libsysfs dependancy,
    call brctl program directly, virBuffer functions cleanups,
    make init script LSB compliant, error handling on lookup functions,
    remove internal virGetDomainByID, revamp of xen subdrivers interfaces
  - Localization updates
* Tue Jun 12 2007 ccoffing@novell.com
- Update to libvirt-0.2.3.
- Fix duplicate files found by rpmlint.
* Wed May 23 2007 ccoffing@novell.com
- Fix rpmlint errors.
* Fri Apr 27 2007 ccoffing@novell.com
- Update to libvirt-0.2.2.
* Wed Mar  7 2007 sbrabec@suse.cz
- Created -doc subpackage (#248813).
- Do not remove valid locales.
- Fixed docdir destination.
- Build with CFLAGS.
- Spec file cleanup.
* Tue Feb 20 2007 jfehlig@novell.com
- Removed usr/lib/libvirt_proxy setuid binary from package.  Fixes
  bug #246610.
* Sat Feb 17 2007 jfehlig@novell.com
- Updated to latest release.  Many of the issues seen in virt-manager
  have been caused by bugs / missing functionality in libvirt.  This
  upate provides a better basis for virt-manager.
* Thu Jan 11 2007 jfehlig@novell.com
- Updated to latest release, version 0.1.10.  Submitting to SLES10 SP1
  to provide base functionality for FATE feature 301181.
  - more localizations
  - bug fixes:
  - VCPU info breakages on xen 3.0.3
  - xenDaemonListDomains buffer overflow (Daniel Berrange)
  - reference count bug when creating Xen domains (Daniel Berrange)
  - improvements:
  - support graphic framebuffer for Xen paravirt (Daniel Berrange)
  - VNC listen IP range support (Daniel Berrange)
  - support for default Xen config files and inactive domains of 3.0.4 (Daniel Berrange)
* Fri Dec  8 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.9.
  - python bindings: release interpeter lock when calling C (Daniel Berrange)
  - don't raise HTTP error when looking informations for a domain
  - some refactoring to use the driver for all entry points
  - better error reporting (Daniel Berrange)
  - fix OS reporting when running as non-root
  - provide XML parsing errors
  - extension of the test framework (Daniel Berrange)
  - fix the reconnect regression test
  - python bindings: Domain instances now link to the Connect to avoid garbage collection and disconnect
  - separate the notion of maximum memory and current use at the XML level
  - Fix a memory leak (Daniel Berrange)
  - add support for shareable drives
  - add support for non-bridge style networking configs for guests(Daniel Berrange)
  - python bindings: fix unsigned long marshalling (Daniel Berrange)
  - new config APIs virConfNew() and virConfSetValue() to build configs from scratch
  - hot plug device support based on Michel Ponceau patch
  - added support for inactive domains, new APIs, various associated cleanup (Daniel Berrange)
  - special device model for HVM guests (Daniel Berrange)
  - add API to dump core of domains (but requires a patched xend)
  - pygrub bootloader informations take over <os> informations
  - updated the localization strings
* Fri Oct 20 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.8.
  - Bug for system with page size != 4k
  - vcpu number initialization (Philippe Berthault)
  - don't label crashed domains as shut off (Peter Vetere)
  - fix virsh man page (Noriko Mizumoto)
  - blktapdd support for alternate drivers like blktap (Daniel Berrange)
  - memory leak fixes (xend interface and XML parsing) (Daniel Berrange)
  - compile fix
  - mlock/munlock size fixes (Daniel Berrange)
  - improve error reporting
- Updated to latest release, version 0.1.7.
  - fix a memory bug on getting vcpu informations from xend (Daniel Berrange)
  - fix another problem in the hypercalls change in Xen changeset
    86d26e6ec89b when getting domain informations (Daniel Berrange)
* Tue Sep 26 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.6.  This release includes
  fix in hypercall driver so local patch has been removed.
* Wed Sep 13 2006 jfehlig@novell.com
- Fixed bug in hypercall driver introduced in version 0.1.5.
  Patch sumbmitted upstream and included locally until next release.
* Mon Sep 11 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.5
  - Support for new hypercalls change in Xen changeset 86d26e6ec89b
  - bug fixes: virParseUUID() was wrong, netwoking for paravirt guestsi
    (Daniel Berrange), virsh on non-existent domains (Daniel Berrange),
    string cast bug when handling error in python (Pete Vetere), HTTP
    500 xend error code handling (Pete Vetere and Daniel Berrange)
  - improvements: test suite for SEXPR <-> XML format conversions (Daniel
    Berrange), virsh output regression suite (Daniel Berrange), new environ
    variable VIRSH_DEFAULT_CONNECT_URI for the default URI when connecting
    (Daniel Berrange), graphical console support for paravirt guests
    (Jeremy Katz), parsing of simple Xen config files (with Daniel Berrange),
    early work on defined (not running) domains (Daniel Berrange),
    virsh output improvement (Daniel Berrange
* Mon Aug 28 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.4
  - bug fixes: spec file fix (Mark McLoughlin), error report problem (with
    Hugh Brock), long integer in Python bindings (with Daniel Berrange), XML
    generation bug for CDRom (Daniel Berrange), bug whem using number() XPath
    function (Mark McLoughlin), fix python detection code, remove duplicate
    initialization errors (Daniel Berrange)
  - improvements: UUID in XML description (Peter Vetere), proxy code
    cleanup, virtual CPU and affinity support + virsh support (Michel
    Ponceau, Philippe Berthault, Daniel Berrange), port and tty informations
    for console in XML (Daniel Berrange), added XML dump to driver and proxy
    support (Daniel Berrange), extention of boot options with support for
    floppy and cdrom (Daniel Berrange), features block in XML to report/ask
    PAE, ACPI, APIC for HVM domains (Daniel Berrange), fail saide-effect
    operations when using read-only connection, large improvements to test
    driver (Daniel Berrange)
  - documentation: spelling (Daniel Berrange), test driver examples.
* Wed Aug 16 2006 jfehlig@novell.com
- Added ExclusiveArch tag so as to only build on x86 and x86_64
* Mon Jul 31 2006 jfehlig@novell.com
- initial submission of libvirt package, version 0.1.3
